@@ -23,7 +23,7 @@ from gammapy.modeling.models import (
 filename = "$GAMMAPY_DATA/catalogs/fermi/Extended_archive_v18/Templates/RXJ1713_2016_250GeV.fits"
 
 m = Map.read(filename)
-m.unit = "sr^-1"
+m = m.copy(unit="sr^-1")
 model = TemplateSpatialModel(m, filename=filename)
 
 model.plot(add_cbar=True)
