@@ -1,7 +1,7 @@
 r"""
 .. _gaussian-spectral-model:
 
-Gaussian Spectral Model
+Gaussian spectral model
 =======================
 
 This model parametrises a gaussian spectrum.
@@ -22,9 +22,9 @@ from astropy import units as u
 import matplotlib.pyplot as plt
 from gammapy.modeling.models import GaussianSpectralModel, Models, SkyModel
 
-energy_range = [0.1, 100] * u.TeV
+energy_bounds = [0.1, 100] * u.TeV
 model = GaussianSpectralModel(norm="1e-2 cm-2 s-1", mean=2 * u.TeV, sigma=0.2 * u.TeV)
-model.plot(energy_range)
+model.plot(energy_bounds)
 plt.grid(which="both")
 plt.ylim(1e-24, 1e-1)
 
