@@ -83,7 +83,6 @@ we show how to work with masks in general:
 
 """
 
-
 ######################################################################
 # Setup
 # -----
@@ -135,7 +134,7 @@ dataset = datasets["Fermi-LAT"]
 # a `mask_fit` it is equal to the safe energy range.
 #
 
-print(f"Fit range : {dataset.energy_range}")
+print(f"Fit range : {dataset.energy_range_total}")
 
 
 ######################################################################
@@ -160,7 +159,7 @@ mask_energy = dataset.counts.geom.energy_mask(10 * u.GeV, 700 * u.GeV)
 #
 
 dataset.mask_fit = mask_energy
-print(f"Fit range : {dataset.energy_range}")
+print(f"Fit range : {dataset.energy_range_total}")
 
 
 ######################################################################
@@ -411,7 +410,7 @@ plt.show()
 
 
 ######################################################################
-# The NOT operator is represented by `~` symbol:
+# The NOT operator is represented by the ``~`` symbol:
 #
 
 significance_mask_inv = ~significance_mask
