@@ -1,5 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import copy
+import html
+import warnings
 from operator import le, lt
 import numpy as np
 import astropy.units as u
@@ -8,6 +10,7 @@ from astropy.table import Table, vstack
 from astropy.time import Time
 from gammapy.utils.scripts import make_path
 from gammapy.utils.time import TIME_REF_DEFAULT, time_ref_from_dict, time_ref_to_dict
+from .metadata import GTIMetaData
 
 __all__ = ["GTI"]
 
@@ -15,7 +18,7 @@ __all__ = ["GTI"]
 class GTI:
     """Good time intervals (GTI) `~astropy.table.Table`.
 
-    Data format specification: :ref:`gadf:iact-gti`
+    Data format specification: :ref:`gadf:iact-gti`.
 
     Note: at the moment dead-time and live-time is in the
     EVENTS header ... the GTI header just deals with
@@ -24,11 +27,10 @@ class GTI:
     Parameters
     ----------
     table : `~astropy.table.Table`
-        GTI table
-    reference_time : `~astropy.time.Time`
-        the reference time
+        GTI table.
+    reference_time : `~astropy.time.Time`, optional
+        The reference time. Default is None.
         If None, use TIME_REF_DEFAULT.
-        Default is None
 
     Examples
     --------
@@ -39,11 +41,12 @@ class GTI:
     >>> print(gti)
     GTI info:
     - Number of GTIs: 1
-    - Duration: 1687.0 s
-    - Start: 123890826.0 s MET
+    - Duration: 1687.0000000000016 s
+    - Start: 123890826.00000001 s MET
     - Start: 2004-12-04T22:08:10.184 (time standard: TT)
-    - Stop: 123892513.0 s MET
+    - Stop: 123892513.00000001 s MET
     - Stop: 2004-12-04T22:36:17.184 (time standard: TT)
+    <BLANKLINE>
 
     Load GTIs for a Fermi-LAT event list:
 
@@ -54,8 +57,9 @@ class GTI:
     - Duration: 183139597.9032163 s
     - Start: 239557417.49417615 s MET
     - Start: 2008-08-04T15:44:41.678 (time standard: TT)
-    - Stop: 460250000.0 s MET
+    - Stop: 460249999.99999994 s MET
     - Stop: 2015-08-02T23:14:24.184 (time standard: TT)
+    <BLANKLINE>
     """
 
     def __init__(self, table, reference_time=None):
@@ -63,11 +67,21 @@ class GTI:
 
         if reference_time is None:
             reference_time = TIME_REF_DEFAULT
-        self._time_ref = Time(reference_time)
+
+        meta = GTIMetaData()
+        meta.reference_time = reference_time
+
+        self._meta = meta
+
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
 
     @staticmethod
     def _validate_table(table):
-        """Checks that the input GTI fits the gammapy internal model."""
+        """Check that the input GTI fits the gammapy internal model."""
         if not isinstance(table, Table):
             raise TypeError("GTI table is not an astropy Table.")
 
@@ -86,22 +100,22 @@ class GTI:
         return table
 
     def copy(self):
+        """Deep copy of the `~gammapy.data.GIT` object."""
         return copy.deepcopy(self)
 
     @classmethod
     def create(cls, start, stop, reference_time=None):
-        """Creates a GTI table from start and stop times.
+        """Create a GTI table from start and stop times.
 
         Parameters
         ----------
         start : `~astropy.time.Time` or `~astropy.units.Quantity`
-            Start times, if a quantity then w.r.t. reference time
+            Start times, if a quantity then w.r.t. reference time.
         stop : `~astropy.time.Time` or `~astropy.units.Quantity`
-            Stop times, if a quantity then w.r.t. reference time
-        reference_time : `~astropy.time.Time`
-            the reference time to use in GTI definition.
+            Stop times, if a quantity then w.r.t. reference time.
+        reference_time : `~astropy.time.Time`, optional
+            The reference time to use in GTI definition. Default is None.
             If None, use TIME_REF_DEFAULT.
-            Default is None
         """
         if reference_time is None:
             reference_time = TIME_REF_DEFAULT
@@ -119,21 +133,31 @@ class GTI:
         return cls(table, reference_time=reference_time)
 
     @classmethod
-    def read(cls, filename, hdu="GTI", format="gadf"):
+    def read(cls, filename, hdu="GTI", format="gadf", checksum=False):
         """Read from FITS file.
 
         Parameters
         ----------
-        filename : `pathlib.Path`, str
+        filename : `pathlib.Path` or str
             Filename
         hdu : str
-            hdu name. Default GTI.
+            hdu name. Default is "GTI".
         format: str
-            Input format, currently only "gadf" is supported
+            Input format, currently only "gadf" is supported. Default is "gadf".
+        checksum : bool
+            If True checks both DATASUM and CHECKSUM cards in the file headers. Default is False.
         """
         filename = make_path(filename)
         with fits.open(str(make_path(filename)), memmap=False) as hdulist:
-            return cls.from_table_hdu(hdulist[hdu], format=format)
+            gti_hdu = hdulist[hdu]
+            if checksum:
+                if gti_hdu.verify_checksum() != 1:
+                    warnings.warn(
+                        f"Checksum verification failed for HDU {hdu} of {filename}.",
+                        UserWarning,
+                    )
+
+            return cls.from_table_hdu(gti_hdu, format=format)
 
     @classmethod
     def from_table_hdu(cls, table_hdu, format="gadf"):
@@ -142,9 +166,9 @@ class GTI:
         Parameters
         ----------
         table_hdu : `~astropy.io.fits.BinTableHDU`
-            table hdu
-        format: str
-            Input format, currently only "gadf" is supported
+            table hdu.
+        format : {"gadf"}
+            Input format, currently only "gadf" is supported. Default is "gadf".
         """
         if format != "gadf":
             raise ValueError(f'Only the "gadf" format supported, got {format}')
@@ -165,13 +189,13 @@ class GTI:
 
         Parameters
         ----------
-        format: str
-            Output format, currently only "gadf" is supported
+        format : str, optional
+            Output format, currently only "gadf" is supported. Default is "gadf".
 
         Returns
         -------
-        hdu: `astropy.io.fits.BinTableHDU`
-            GTI table converted to FITS representation
+        hdu : `astropy.io.fits.BinTableHDU`
+            GTI table converted to FITS representation.
         """
         if format != "gadf":
             raise ValueError(f'Only the "gadf" format supported, got {format}')
@@ -189,8 +213,10 @@ class GTI:
 
         Parameters
         ----------
-        filename : str or `Path`
-            File name to write to.
+        filename : str or `~pathlib.Path`
+            Filename.
+        **kwargs : dict, optional
+            Keyword arguments passed to `~astropy.io.fits.HDUList.writeto`.
         """
         hdu = self.to_table_hdu()
         hdulist = fits.HDUList([fits.PrimaryHDU(), hdu])
@@ -213,43 +239,43 @@ class GTI:
 
     @property
     def time_delta(self):
-        """GTI durations in seconds (`~astropy.units.Quantity`)."""
+        """GTI durations in seconds as a `~astropy.units.Quantity`."""
         delta = self.time_stop - self.time_start
         return delta.to("s")
 
     @property
     def time_ref(self):
-        """Time reference (`~astropy.time.Time`)."""
-        return self._time_ref
+        """Time reference as a `~astropy.time.Time` object."""
+        return self._meta.reference_time
 
     @property
     def time_sum(self):
-        """Sum of GTIs in seconds (`~astropy.units.Quantity`)."""
+        """Sum of GTIs in seconds as a `~astropy.units.Quantity`."""
         return self.time_delta.sum()
 
     @property
     def time_start(self):
-        """GTI start times (`~astropy.time.Time`)."""
+        """GTI start times as a `~astropy.time.Time` object."""
         return self.table["START"]
 
     @property
     def time_stop(self):
-        """GTI end times (`~astropy.time.Time`)."""
+        """GTI end times as a `~astropy.time.Time` object."""
         return self.table["STOP"]
 
     @property
     def met_start(self):
-        """GTI start time difference with reference time in sec, MET (`~astropy.units.Quantity`)."""
+        """GTI start time difference with reference time in seconds, MET as a `~astropy.units.Quantity`."""
         return (self.time_start - self.time_ref).to("s")
 
     @property
     def met_stop(self):
-        """GTI start time difference with reference time in sec, MET (`~astropy.units.Quantity`)."""
+        """GTI start time difference with reference time in seconds, MET as a `~astropy.units.Quantity`."""
         return (self.time_stop - self.time_ref).to("s")
 
     @property
     def time_intervals(self):
-        """List of time intervals"""
+        """List of time intervals."""
         return [
             (t_start, t_stop)
             for t_start, t_stop in zip(self.time_start, self.time_stop)
@@ -257,13 +283,13 @@ class GTI:
 
     @classmethod
     def from_time_intervals(cls, time_intervals, reference_time=None):
-        """From list of time intervals
+        """From list of time intervals.
 
         Parameters
         ----------
         time_intervals : list of `~astropy.time.Time` objects
-            Time intervals
-        reference_time : `~astropy.time.Time`
+            Time intervals.
+        reference_time : `~astropy.time.Time`, optional
             Reference time to use in GTI definition. Default is None.
             If None, use TIME_REF_DEFAULT.
 
@@ -311,6 +337,35 @@ class GTI:
 
         return self.__class__(gti_within)
 
+    def delete_interval(self, time_interval):
+        """Select and crop GTIs in time interval.
+
+        Parameters
+        ----------
+        time_interval : [`astropy.time.Time`, `astropy.time.Time`]
+            Start and stop time for the selection.
+
+        Returns
+        -------
+        gti : `GTI`
+            Copy of the GTI table with the bad time interval deleted.
+        """
+        interval_start, interval_stop = time_interval
+        interval_start.format = self.time_start.format
+        interval_stop.format = self.time_stop.format
+
+        trim_table = self.table.copy()
+
+        trim_table["STOP"][
+            (self.time_start < interval_start) & (self.time_stop > interval_start)
+        ] = interval_start
+        trim_table["START"][
+            (self.time_start < interval_stop) & (self.time_stop > interval_stop)
+        ] = interval_stop
+        mask = (self.time_stop > interval_stop) | (self.time_start < interval_start)
+
+        return self.__class__(trim_table[mask])
+
     def stack(self, other):
         """Stack with another GTI in place.
 
@@ -320,8 +375,7 @@ class GTI:
         Parameters
         ----------
         other : `~gammapy.data.GTI`
-            GTI to stack to self
-
+            GTI to stack to self.
         """
         self.table = self._validate_table(vstack([self.table, other.table]))
 
@@ -334,9 +388,9 @@ class GTI:
         Parameters
         ----------
         gtis : list of `GTI`
-            List of good time intervals to stack
-        **kwargs : dict
-            Keywords passed on to `~astropy.table.vstack`
+            List of good time intervals to stack.
+        **kwargs : dict, optional
+            Keywords passed on to `~astropy.table.vstack`.
 
         Returns
         -------
@@ -354,11 +408,11 @@ class GTI:
 
         Parameters
         ----------
-        overlap_ok : bool
-            Whether to raise an error when overlapping time bins are found.
-        merge_equal : bool
+        overlap_ok : bool, optional
+            Whether to raise an error when overlapping time bins are found. Default is True.
+        merge_equal : bool; optional
             Whether to merge touching time bins e.g. ``(1, 2)`` and ``(2, 3)``
-            will result in ``(1, 3)``.
+            will result in ``(1, 3)``. Default is True.
         """
         # Algorithm to merge overlapping intervals is well-known,
         # see e.g. https://stackoverflow.com/a/43600953/498873
@@ -392,9 +446,9 @@ class GTI:
         Parameters
         ----------
         time_intervals : list of `astropy.time.Time`
-            Start and stop time for each interval to compute the LC
+            Start and stop time for each interval to compute the LC.
         atol : `~astropy.units.Quantity`
-            Tolerance value for time comparison with different scale. Default 1e-6 sec.
+            Tolerance value for time comparison with different scale. Default is "1e-6 s".
 
         Returns
         -------
