@@ -190,9 +190,6 @@ def test_observations_mutation(data_store):
     with pytest.raises(TypeError):
         obss[5] = "bad"
 
-    with pytest.raises(TypeError):
-        obss[["1", "2"]]
-
 
 def test_empty_observations():
     observations = Observations()
@@ -378,6 +375,8 @@ def test_observation_write(tmp_path):
     obs = Observation.read(
         "$GAMMAPY_DATA/hess-dl3-dr1/data/hess_dl3_dr1_obs_id_023523.fits.gz"
     )
+    mjdreff = obs.events.table.meta["MJDREFF"]
+    mjdrefi = obs.events.table.meta["MJDREFI"]
     path = tmp_path / "obs.fits.gz"
 
     obs.meta.creation.origin = "test"
@@ -393,6 +392,9 @@ def test_observation_write(tmp_path):
     assert obs_read.obs_id == 23523
     assert_allclose(obs_read.observatory_earth_location.lat.deg, -23.271778)
 
+    assert_allclose(obs_read.events.table.meta["MJDREFF"], mjdreff)
+    assert_allclose(obs_read.events.table.meta["MJDREFI"], mjdrefi)
+
     # unsupported format
     with pytest.raises(ValueError):
         obs.write(tmp_path / "foo.fits.gz", format="cool-new-format")
@@ -578,13 +580,6 @@ def test_stack_observations(data_store, caplog):
         Observations.from_stack([obs_1, ["a"]])
 
 
-@requires_data()
-def test_slice(data_store):
-    obs_1 = data_store.get_observations([20136, 20137, 20151])
-    assert isinstance(obs_1[0], Observation)
-    assert isinstance(obs_1[1:], Observations)
-
-
 @requires_data()
 def test_observations_generator(data_store):
     """Test Observations.generator()"""
@@ -623,3 +618,40 @@ def test_event_setter():
     events = EventList(Table())
     obs.events = events
     assert obs.events is events
+
+
+@requires_data()
+def test_observations_getitem(data_store):
+    """Test mask indexing on Observations"""
+    obs_1 = data_store.get_observations([20136, 20137, 20151])
+
+    assert isinstance(obs_1[0], Observation)
+    assert isinstance(obs_1[1:], Observations)
+    assert len(obs_1[1:]) == 2
+
+    mask = [True, False, True]
+    obs_2 = obs_1[mask]
+
+    assert len(obs_2) == 2
+    assert obs_2.ids == ["20136", "20151"]
+
+    ind = [0, 2]
+    obs_2 = obs_1[ind]
+
+    assert len(obs_2) == 2
+    assert obs_2.ids == ["20136", "20151"]
+
+    obs_2 = obs_1[np.array(mask)]
+
+    assert len(obs_2) == 2
+    assert obs_2.ids == ["20136", "20151"]
+
+    assert obs_1[["20136", "20151"]].ids == ["20136", "20151"]
+
+    obs_2 = obs_1[[]]
+    assert len(obs_2) == 0
+    assert isinstance(obs_2, Observations)
+
+    obs_2 = obs_1[np.array([])]
+    assert len(obs_2) == 0
+    assert isinstance(obs_2, Observations)
