@@ -6,14 +6,14 @@ from .io import OGIPDatasetReader, OGIPDatasetWriter
 from .map import (
     MapDataset,
     MapDatasetOnOff,
+    create_empty_map_dataset_from_irfs,
     create_map_dataset_from_observation,
     create_map_dataset_geoms,
 )
-from .simulate import MapDatasetEventSampler, ObservationEventSampler
-from .map import MapDataset, MapDatasetOnOff, create_map_dataset_geoms
 from .metadata import MapDatasetMetaData
-from .simulate import MapDatasetEventSampler
+from .simulate import MapDatasetEventSampler, ObservationEventSampler
 from .spectrum import SpectrumDataset, SpectrumDatasetOnOff
+from .utils import apply_edisp, split_dataset
 
 DATASET_REGISTRY = Registry(
     [
@@ -28,6 +28,7 @@ DATASET_REGISTRY = Registry(
 """Registry of dataset classes in Gammapy."""
 
 __all__ = [
+    "create_empty_map_dataset_from_irfs",
     "create_map_dataset_from_observation",
     "create_map_dataset_geoms",
     "Dataset",
@@ -43,4 +44,6 @@ __all__ = [
     "SpectrumDataset",
     "SpectrumDatasetOnOff",
     "MapDatasetMetaData",
+    "apply_edisp",
+    "split_dataset",
 ]
