@@ -1,6 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import logging
 import numpy as np
+from scipy.special import erfc
 from astropy import units as u
 from astropy.io import fits
 from astropy.table import Table
@@ -14,6 +15,7 @@ from gammapy.modeling.models import (
     SkyModel,
     TemplateSpatialModel,
 )
+from gammapy.utils.interpolation import interpolate_profile
 from gammapy.utils.scripts import make_name, make_path
 from .core import Dataset
 
@@ -37,8 +39,7 @@ def _get_reference_model(model, energy_bounds, margin_percent=70):
 
 
 class FluxPointsDataset(Dataset):
-    """Bundle a set of flux points with a parametric model,
-    to compute fit statistic function using chi2 statistics.
+    """Bundle a set of flux points with a parametric model, to compute fit statistic function using different statistics (see ``stat_type``).
 
     For more information see :ref:`datasets`.
 
@@ -55,6 +56,23 @@ class FluxPointsDataset(Dataset):
     meta_table : `~astropy.table.Table`
         Table listing information on observations used to create the dataset.
         One line per observation for stacked datasets.
+    stat_type : str
+        Method used to compute the statistics:
+
+                * chi2 : estimate from chi2 statistics.
+                * profile : estimate from interpolation of the likelihood profile.
+                * distrib : Assuming gaussian errors the likelihood is given by the probability density function
+                  of the normal distribution. For the upper limit case it is necessary to marginalize over the unknown
+                  measurement, so we integrate the normal distribution up to the upper limit value which gives the
+                  complementary error function. See eq. C7 of `Mohanty et al (2013) <https://iopscience.iop.org/article/10.1088/0004-637X/773/2/168/pdf>`__
+
+        Default is `chi2`, in that case upper limits are ignored and the mean of asymetrics error is used.
+        However, it is recommended to use `profile` if `stat_scan` is available on flux points.
+        The `distrib` case provides an approximation if the profile is not available.
+    stat_kwargs : dict
+        Extra arguments specifying the interpolation scheme of the likelihood profile.
+        Used only if `stat_type=="profile"`. In that case the default is :
+        `stat_kwargs={"interp_scale":"sqrt", "extrapolate":True}`
 
     Examples
     --------
@@ -91,18 +109,17 @@ class FluxPointsDataset(Dataset):
         message    : Hesse terminated successfully.
 
     >>> print(result.parameters.to_table())
-    type    name     value         unit      ... frozen is_norm link prior
-    ---- --------- ---------- -------------- ... ------ ------- ---- -----
-             index 2.2159e+00                ...  False   False
-         amplitude 2.1619e-13 TeV-1 s-1 cm-2 ...  False    True
-         reference 1.0000e+00            TeV ...   True   False
+    type    name     value         unit      ... frozen link prior
+    ---- --------- ---------- -------------- ... ------ ---- -----
+             index 2.2159e+00                ...  False
+         amplitude 2.1619e-13 TeV-1 s-1 cm-2 ...  False
+         reference 1.0000e+00            TeV ...   True
 
     Note: In order to reproduce the example, you need the tests datasets folder.
     You may download it with the command:
     ``gammapy download datasets --tests --out $GAMMAPY_DATA``
     """
 
-    stat_type = "chi2"
     tag = "FluxPointsDataset"
 
     def __init__(
@@ -113,6 +130,8 @@ class FluxPointsDataset(Dataset):
         mask_safe=None,
         name=None,
         meta_table=None,
+        stat_type="chi2",
+        stat_kwargs=None,
     ):
         if not data.geom.has_energy_axis:
             raise ValueError("FluxPointsDataset needs an energy axis")
@@ -122,11 +141,61 @@ class FluxPointsDataset(Dataset):
         self.models = models
         self.meta_table = meta_table
 
-        if mask_safe is None:
-            mask_safe = (~data.is_ul).data
+        self._available_stat_type = dict(
+            chi2=self._stat_array_chi2,
+            profile=self._stat_array_profile,
+            distrib=self._stat_array_distrib,
+        )
 
+        if stat_kwargs is None:
+            stat_kwargs = dict()
+        self.stat_kwargs = stat_kwargs
+
+        self.stat_type = stat_type
+
+        if mask_safe is None:
+            mask_safe = np.ones(self.data.dnde.data.shape, dtype=bool)
         self.mask_safe = mask_safe
 
+    @property
+    def available_stat_type(self):
+        return list(self._available_stat_type.keys())
+
+    @property
+    def stat_type(self):
+        return self._stat_type
+
+    @stat_type.setter
+    def stat_type(self, stat_type):
+        if stat_type not in self.available_stat_type:
+            raise ValueError(
+                f"Invalid stat_type: possible options are {self.available_stat_type}"
+            )
+
+        if stat_type == "chi2":
+            self._mask_valid = (~self.data.is_ul).data & np.isfinite(self.data.dnde)
+        elif stat_type == "distrib":
+            self._mask_valid = (
+                self.data.is_ul.data & np.isfinite(self.data.dnde_ul)
+            ) | np.isfinite(self.data.dnde)
+        elif stat_type == "profile":
+            self.stat_kwargs.setdefault("interp_scale", "sqrt")
+            self.stat_kwargs.setdefault("extrapolate", True)
+            self._profile_interpolators = self._get_valid_profile_interpolators()
+        self._stat_type = stat_type
+
+    @property
+    def mask_valid(self):
+        return self._mask_valid
+
+    @property
+    def mask_safe(self):
+        return self._mask_safe & self.mask_valid
+
+    @mask_safe.setter
+    def mask_safe(self, mask_safe):
+        self._mask_safe = mask_safe
+
     @property
     def name(self):
         return self._name
@@ -310,13 +379,86 @@ class FluxPointsDataset(Dataset):
 
     def stat_array(self):
         """Fit statistic array."""
+        return self._available_stat_type[self.stat_type]()
+
+    def _stat_array_chi2(self):
+        """Chi2 statistics."""
         model = self.flux_pred()
         data = self.data.dnde.quantity
         try:
-            sigma = self.data.dnde_err
+            sigma = self.data.dnde_err.quantity
         except AttributeError:
-            sigma = (self.data.dnde_errn + self.data.dnde_errp) / 2
-        return ((data - model) / sigma.quantity).to_value("") ** 2
+            sigma = (self.data.dnde_errn + self.data.dnde_errp).quantity / 2
+        return ((data - model) / sigma).to_value("") ** 2
+
+    def _stat_array_profile(self):
+        """Estimate statitistic from interpolation of the likelihood profile."""
+        model = np.zeros(self.data.dnde.data.shape) + (
+            self.flux_pred() / self.data.dnde_ref
+        ).to_value("")
+        stat = np.zeros(model.shape)
+        for idx in np.ndindex(self._profile_interpolators.shape):
+            stat[idx] = self._profile_interpolators[idx](model[idx])
+        return stat
+
+    def _get_valid_profile_interpolators(self):
+        value_scan = self.data.stat_scan.geom.axes["norm"].center
+        shape_axes = self.data.stat_scan.geom._shape[slice(3, None)][::-1]
+        interpolators = np.empty(shape_axes, dtype=object)
+        self._mask_valid = np.ones(self.data.dnde.data.shape, dtype=bool)
+        for idx in np.ndindex(shape_axes):
+            stat_scan = np.abs(
+                self.data.stat_scan.data[idx].squeeze()
+                - self.data.stat.data[idx].squeeze()
+            )
+            self._mask_valid[idx] = np.all(np.isfinite(stat_scan))
+            interpolators[idx] = interpolate_profile(
+                value_scan,
+                stat_scan,
+                interp_scale=self.stat_kwargs["interp_scale"],
+                extrapolate=self.stat_kwargs["extrapolate"],
+            )
+        return interpolators
+
+    def _stat_array_distrib(self):
+        """Estimate statistic from probability distributions,
+        assumes that flux points correspond to asymmetric gaussians
+        and upper limits complementary error functions.
+        """
+
+        model = np.zeros(self.data.dnde.data.shape) + self.flux_pred().to_value(
+            self.data.dnde.unit
+        )
+
+        stat = np.zeros(model.shape)
+
+        mask_valid = ~np.isnan(self.data.dnde.data)
+        loc = self.data.dnde.data[mask_valid]
+        value = model[mask_valid]
+        try:
+            mask_p = (model >= self.data.dnde.data)[mask_valid]
+            scale = np.zeros(mask_p.shape)
+            scale[mask_p] = self.data.dnde_errp.data[mask_valid][mask_p]
+            scale[~mask_p] = self.data.dnde_errn.data[mask_valid][~mask_p]
+
+            mask_invalid = np.isnan(scale)
+            scale[mask_invalid] = self.data.dnde_err.data[mask_valid][mask_invalid]
+        except AttributeError:
+            scale = self.data.dnde_err.data[mask_valid]
+
+        stat[mask_valid] = ((value - loc) / scale) ** 2
+
+        mask_ul = self.data.is_ul.data
+        value = model[mask_ul]
+        loc_ul = self.data.dnde_ul.data[mask_ul]
+        scale_ul = self.data.dnde_ul.data[mask_ul]
+        stat[mask_ul] = 2 * np.log(
+            (erfc((loc_ul - value) / scale_ul) / 2)
+            / (erfc((loc_ul - 0) / scale_ul) / 2)
+        )
+
+        stat[np.isnan(stat.data)] = 0
+        return stat
 
     def residuals(self, method="diff"):
         """Compute flux point residuals.
@@ -325,9 +467,9 @@ class FluxPointsDataset(Dataset):
         ----------
         method: {"diff", "diff/model"}
             Method used to compute the residuals. Available options are:
-                - `diff` (default): data - model.
-                - `diff/model`: (data - model) / model.
-            Default is "diff".
+
+            - ``"diff"`` (default): data - model.
+            - ``"diff/model"``: (data - model) / model.
 
         Returns
         -------
@@ -349,7 +491,6 @@ class FluxPointsDataset(Dataset):
         ax_residuals=None,
         kwargs_spectrum=None,
         kwargs_residuals=None,
-        axis_name="energy",
     ):
         """Plot flux points, best fit model and residuals in two panels.
 
@@ -365,6 +506,7 @@ class FluxPointsDataset(Dataset):
             Keyword arguments passed to `~FluxPointsDataset.plot_spectrum`. Default is None.
         kwargs_residuals : dict, optional
             Keyword arguments passed to `~FluxPointsDataset.plot_residuals`. Default is None.
+
         Returns
         -------
         ax_spectrum, ax_residuals : `~matplotlib.axes.Axes`
@@ -394,6 +536,8 @@ class FluxPointsDataset(Dataset):
         gs = GridSpec(7, 1)
         if ax_spectrum is None:
             ax_spectrum = fig.add_subplot(gs[:5, :])
+            if ax_residuals is None:
+                plt.setp(ax_spectrum.get_xticklabels(), visible=False)
 
         if ax_residuals is None:
             ax_residuals = fig.add_subplot(gs[5:, :], sharex=ax_spectrum)
@@ -448,9 +592,10 @@ class FluxPointsDataset(Dataset):
 
         if method == "diff/model":
             model = self.flux_pred()
-            yerr = (yerr[0].quantity / model).squeeze(), (
-                yerr[1].quantity / model
-            ).squeeze()
+            yerr = (
+                (yerr[0].quantity / model).squeeze(),
+                (yerr[1].quantity / model).squeeze(),
+            )
         elif method == "diff":
             yerr = yerr[0].quantity.squeeze(), yerr[1].quantity.squeeze()
         else:
