@@ -60,23 +60,27 @@ class OGIPDatasetWriter(DatasetWriter):
 
     Parameters
     ----------
-    filename : `pathlib.Path` or str
-        Filename
+    filename : `~pathlib.Path` or str
+        Filename.
     format : {"ogip", "ogip-sherpa"}
-        Which format to use
-    overwrite : bool
-        Overwrite existing files?
+        Which format to use. Default is 'ogip'.
+    overwrite : bool, optional
+        Overwrite existing files. Default is False.
+    checksum : bool
+        When True adds both DATASUM and CHECKSUM cards to the headers written to the files.
+        Default is False.
     """
 
     tag = ["ogip", "ogip-sherpa"]
 
-    def __init__(self, filename, format="ogip", overwrite=False):
+    def __init__(self, filename, format="ogip", overwrite=False, checksum=False):
         filename = make_path(filename)
         filename.parent.mkdir(exist_ok=True, parents=True)
 
         self.filename = filename
         self.format = format
         self.overwrite = overwrite
+        self.checksum = checksum
 
     @staticmethod
     def get_filenames(filename):
@@ -85,12 +89,12 @@ class OGIPDatasetWriter(DatasetWriter):
         Parameters
         ----------
         filename : `~pathlib.Path`
-            Filename
+            Filename.
 
         Returns
         -------
         filenames : dict
-            Dict of filenames
+            Dictionary of filenames.
         """
         suffix = "".join(filename.suffixes)
         name = filename.name.replace(suffix, "")
@@ -124,10 +128,10 @@ class OGIPDatasetWriter(DatasetWriter):
         filenames = OGIPDatasetWriter.get_filenames(self.filename)
         meta["ANCRFILE"] = filenames["ancrfile"]
 
-        if dataset.edisp:
+        if dataset.counts_off:
             meta["BACKFILE"] = filenames["backfile"]
 
-        if dataset.counts_off:
+        if dataset.edisp:
             meta["RESPFILE"] = filenames["respfile"]
 
         return meta
@@ -138,7 +142,7 @@ class OGIPDatasetWriter(DatasetWriter):
         Parameters
         ----------
         dataset : `SpectrumDatasetOnOff`
-            Dataset to write
+            Dataset to write.
         """
         filenames = self.get_filenames(self.filename)
 
@@ -159,12 +163,17 @@ class OGIPDatasetWriter(DatasetWriter):
         Parameters
         ----------
         dataset : `SpectrumDatasetOnOff`
-            Dataset to write
-        filename : str or `Path`
-            Filename to use
+            Dataset to write.
+        filename : str or `~pathlib.Path`
+            Filename to use.
         """
         kernel = dataset.edisp.get_edisp_kernel()
-        kernel.write(filename=filename, overwrite=self.overwrite, format=self.format)
+        kernel.write(
+            filename=filename,
+            format=self.format,
+            checksum=self.checksum,
+            overwrite=self.overwrite,
+        )
 
     def write_arf(self, dataset, filename):
         """Write effective area.
@@ -172,9 +181,9 @@ class OGIPDatasetWriter(DatasetWriter):
         Parameters
         ----------
         dataset : `SpectrumDatasetOnOff`
-            Dataset to write
-        filename : str or `Path`
-            Filename to use
+            Dataset to write.
+        filename : str or `~pathlib.Path`
+            Filename to use.
 
         """
         aeff = dataset.exposure / dataset.exposure.meta["livetime"]
@@ -182,6 +191,7 @@ class OGIPDatasetWriter(DatasetWriter):
             filename=filename,
             overwrite=self.overwrite,
             format=self.format.replace("ogip", "ogip-arf"),
+            checksum=self.checksum,
         )
 
     def to_counts_hdulist(self, dataset, is_bkg=False):
@@ -190,9 +200,9 @@ class OGIPDatasetWriter(DatasetWriter):
         Parameters
         ----------
         dataset : `SpectrumDatasetOnOff`
-            Dataset to write
+            Dataset to write.
         is_bkg : bool
-            Whether to use counts off
+            Whether to use counts off. Default is False.
         """
         counts = dataset.counts_off if is_bkg else dataset.counts
         acceptance = dataset.acceptance_off if is_bkg else dataset.acceptance
@@ -224,9 +234,9 @@ class OGIPDatasetWriter(DatasetWriter):
         Parameters
         ----------
         dataset : `SpectrumDatasetOnOff`
-            Dataset to write
-        filename : str or `Path`
-            Filename to use
+            Dataset to write.
+        filename : str or `~pathlib.Path`
+            Filename to use.
 
         """
         hdulist = self.to_counts_hdulist(dataset)
@@ -235,7 +245,7 @@ class OGIPDatasetWriter(DatasetWriter):
             hdu = dataset.gti.to_table_hdu()
             hdulist.append(hdu)
 
-        hdulist.writeto(filename, overwrite=self.overwrite)
+        hdulist.writeto(filename, overwrite=self.overwrite, checksum=self.checksum)
 
     def write_bkg(self, dataset, filename):
         """Write off counts file.
@@ -243,12 +253,12 @@ class OGIPDatasetWriter(DatasetWriter):
         Parameters
         ----------
         dataset : `SpectrumDatasetOnOff`
-            Dataset to write
-        filename : str or `Path`
-            Filename to use
+            Dataset to write.
+        filename : str or `~pathlib.Path`
+            Filename to use.
         """
         hdulist = self.to_counts_hdulist(dataset, is_bkg=True)
-        hdulist.writeto(filename, overwrite=self.overwrite)
+        hdulist.writeto(filename, overwrite=self.overwrite, checksum=self.checksum)
 
 
 class OGIPDatasetReader(DatasetReader):
@@ -268,13 +278,16 @@ class OGIPDatasetReader(DatasetReader):
     Parameters
     ----------
     filename : str or `~pathlib.Path`
-        OGIP PHA file to read
+        OGIP PHA file to read.
+    checksum : bool
+        If True checks both DATASUM and CHECKSUM cards in the file headers. Default is False.
     """
 
     tag = "ogip"
 
-    def __init__(self, filename):
+    def __init__(self, filename, checksum=False):
         self.filename = make_path(filename)
+        self.checksum = checksum
 
     def get_valid_path(self, filename):
         """Get absolute or relative path.
@@ -283,13 +296,13 @@ class OGIPDatasetReader(DatasetReader):
 
         Parameters
         ----------
-        filename : str or `Path`
-            Filename
+        filename : str or `~pathlib.Path`
+            Filename.
 
         Returns
         -------
-        filename : `Path`
-            Valid path
+        filename : `~pathlib.Path`
+            Valid path.
         """
         filename = make_path(filename)
 
@@ -304,13 +317,13 @@ class OGIPDatasetReader(DatasetReader):
         Parameters
         ----------
         pha_meta : dict
-            Meta data from the PHA file
+            Metadata from the PHA file.
 
         Returns
         -------
         filenames : dict
-            Dict with filenames of "arffile", "rmffile" (optional)
-            and "bkgfile" (optional)
+            Dictionary with filenames of "arffile", "rmffile" (optional)
+            and "bkgfile" (optional).
         """
         filenames = {"arffile": self.get_valid_path(pha_meta["ANCRFILE"])}
 
@@ -323,22 +336,24 @@ class OGIPDatasetReader(DatasetReader):
         return filenames
 
     @staticmethod
-    def read_pha(filename):
+    def read_pha(filename, checksum=False):
         """Read PHA file.
 
         Parameters
         ----------
-        filename : str or `Path`
-            PHA file name
+        filename : str or `~pathlib.Path`
+            PHA file name.
+        checksum : bool
+            If True checks both DATASUM and CHECKSUM cards in the file headers. Default is False.
 
         Returns
         -------
         data : dict
-            Dict with counts, acceptance and mask_safe
+            Dictionary with counts, acceptance and mask_safe.
         """
         data = {}
 
-        with fits.open(filename, memmap=False) as hdulist:
+        with fits.open(filename, memmap=False, checksum=checksum) as hdulist:
             data["counts"] = RegionNDMap.from_hdulist(hdulist, format="ogip")
             data["acceptance"] = RegionNDMap.from_hdulist(
                 hdulist, format="ogip", ogip_column="BACKSCAL"
@@ -354,20 +369,22 @@ class OGIPDatasetReader(DatasetReader):
         return data
 
     @staticmethod
-    def read_bkg(filename):
+    def read_bkg(filename, checksum=False):
         """Read PHA background file.
 
         Parameters
         ----------
-        filename : str or `Path`
-            PHA file name
+        filename : str or `~pathlib.Path`
+            PHA file name.
+        checksum : bool
+            If True checks both DATASUM and CHECKSUM cards in the file headers. Default is False.
 
         Returns
         -------
         data : dict
-            Dict with counts_off and acceptance_off
+            Dictionary with counts_off and acceptance_off.
         """
-        with fits.open(filename, memmap=False) as hdulist:
+        with fits.open(filename, memmap=False, checksum=checksum) as hdulist:
             counts_off = RegionNDMap.from_hdulist(hdulist, format="ogip")
             acceptance_off = RegionNDMap.from_hdulist(
                 hdulist, ogip_column="BACKSCAL", format="ogip"
@@ -375,22 +392,24 @@ class OGIPDatasetReader(DatasetReader):
         return {"counts_off": counts_off, "acceptance_off": acceptance_off}
 
     @staticmethod
-    def read_rmf(filename, exposure):
+    def read_rmf(filename, exposure, checksum=False):
         """Read RMF file.
 
         Parameters
         ----------
-        filename : str or `Path`
-            PHA file name
+        filename : str or `~pathlib.Path`
+            PHA file name.
         exposure : `RegionNDMap`
-            Exposure map
+            Exposure map.
+        checksum : bool
+            If True checks both DATASUM and CHECKSUM cards in the file headers. Default is False.
 
         Returns
         -------
         data : `EDispKernelMap`
-            Dict with edisp
+            Dictionary with edisp.
         """
-        kernel = EDispKernel.read(filename)
+        kernel = EDispKernel.read(filename, checksum=checksum)
         edisp = EDispKernelMap.from_edisp_kernel(kernel, geom=exposure.geom)
 
         # TODO: resolve this separate handling of exposure for edisp
@@ -398,22 +417,24 @@ class OGIPDatasetReader(DatasetReader):
         return edisp
 
     @staticmethod
-    def read_arf(filename, livetime):
+    def read_arf(filename, livetime, checksum=False):
         """Read ARF file.
 
         Parameters
         ----------
-        filename : str or `Path`
-            PHA file name
+        filename : str or `~pathlib.Path`
+            PHA file name.
         livetime : `Quantity`
-            Livetime
+            Livetime.
+        checksum : bool
+            If True checks both DATASUM and CHECKSUM cards in the file headers. Default is False.
 
         Returns
         -------
         data : `RegionNDMap`
-            Exposure map
+            Exposure map.
         """
-        aeff = RegionNDMap.read(filename, format="ogip-arf")
+        aeff = RegionNDMap.read(filename, format="ogip-arf", checksum=checksum)
         exposure = aeff * livetime
         exposure.meta["livetime"] = livetime
         return exposure
@@ -424,22 +445,26 @@ class OGIPDatasetReader(DatasetReader):
         Returns
         -------
         dataset : SpectrumDatasetOnOff
-            Spectrum dataset
+            Spectrum dataset.
         """
-        kwargs = self.read_pha(self.filename)
+        kwargs = self.read_pha(self.filename, checksum=self.checksum)
         pha_meta = kwargs["counts"].meta
 
         name = str(pha_meta["OBS_ID"])
         livetime = pha_meta["EXPOSURE"] * u.s
 
         filenames = self.get_filenames(pha_meta=pha_meta)
-        exposure = self.read_arf(filenames["arffile"], livetime=livetime)
+        exposure = self.read_arf(
+            filenames["arffile"], livetime=livetime, checksum=self.checksum
+        )
 
         if "bkgfile" in filenames:
-            bkg = self.read_bkg(filenames["bkgfile"])
+            bkg = self.read_bkg(filenames["bkgfile"], checksum=self.checksum)
             kwargs.update(bkg)
 
         if "rmffile" in filenames:
-            kwargs["edisp"] = self.read_rmf(filenames["rmffile"], exposure=exposure)
+            kwargs["edisp"] = self.read_rmf(
+                filenames["rmffile"], exposure=exposure, checksum=self.checksum
+            )
 
         return SpectrumDatasetOnOff(name=name, exposure=exposure, **kwargs)
