@@ -1,6 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Simulate observations."""
+
 import html
+import logging
 from copy import deepcopy
 import numpy as np
 import astropy.units as u
@@ -21,6 +23,8 @@ from .map import create_map_dataset_from_observation
 
 __all__ = ["MapDatasetEventSampler", "ObservationEventSampler"]
 
+log = logging.getLogger(__name__)
+
 
 class MapDatasetEventSampler:
     """Sample events from a map dataset.
@@ -191,6 +195,7 @@ class MapDatasetEventSampler:
 
         npred = self._evaluate_timevar_source(dataset, model=model)
         data = npred.data[np.isfinite(npred.data)]
+        data = np.clip(data, 0, None)
 
         try:
             n_events = self.random_state.poisson(np.sum(data))
@@ -201,7 +206,9 @@ class MapDatasetEventSampler:
 
         coords = npred.sample_coord(n_events=n_events, random_state=self.random_state)
 
-        coords["time"] = Time(coords["time"], format="mjd", scale="tt")
+        coords["time"] = Time(
+            coords["time"], format="mjd", scale=dataset.gti.time_ref.scale
+        )
 
         table = self._make_table(coords, dataset.gti.time_ref)
 
@@ -225,6 +232,7 @@ class MapDatasetEventSampler:
             Table of sampled events.
         """
         data = npred.data[np.isfinite(npred.data)]
+        data = np.clip(data, 0, None)
         n_events = self.random_state.poisson(np.sum(data))
 
         coords = npred.sample_coord(n_events=n_events, random_state=self.random_state)
@@ -242,26 +250,34 @@ class MapDatasetEventSampler:
 
         return table
 
-    def sample_sources(self, dataset):
+    def sample_sources(self, dataset, psf_update=False):
         """Sample source model components.
 
         Parameters
         ----------
         dataset : `~gammapy.datasets.MapDataset`
             Map dataset.
+        psf_update : bool
+            Parameter to switch-off (on) the update of the PSF
+            in the dataset; default is False.
 
         Returns
         -------
         events : `~gammapy.data.EventList`
             Event list.
         """
+        if psf_update is True:
+            psf_update = dataset.psf
+        else:
+            psf_update = None
 
         events_all = EventList(Table())
         for idx, evaluator in enumerate(dataset.evaluators.values()):
+            log.info(f"Evaluating model: {evaluator.model.name}")
             if evaluator.needs_update:
                 evaluator.update(
                     dataset.exposure,
-                    dataset.psf,
+                    psf_update,
                     dataset.edisp,
                     dataset._geom,
                     dataset.mask,
@@ -310,6 +326,7 @@ class MapDatasetEventSampler:
 
         table = Table()
         if dataset.background:
+            log.info("Evaluating background...")
             background = dataset.npred_background()
 
             temporal_model = ConstantTemporalModel()
@@ -436,9 +453,9 @@ class MapDatasetEventSampler:
 
         meta["HDUCLAS1"] = "EVENTS"
         meta["EXTNAME"] = "EVENTS"
-        meta[
-            "HDUDOC"
-        ] = "https://github.com/open-gamma-ray-astro/gamma-astro-data-formats"
+        meta["HDUDOC"] = (
+            "https://github.com/open-gamma-ray-astro/gamma-astro-data-formats"
+        )
         meta["HDUVERS"] = "0.2"
         meta["HDUCLASS"] = "GADF"
 
@@ -469,15 +486,15 @@ class MapDatasetEventSampler:
         meta["DSREF1"] = ":GTI"
         meta["DSTYP2"] = "ENERGY"
         meta["DSUNI2"] = "TeV"
-        meta[
-            "DSVAL2"
-        ] = f'{dataset._geom.axes["energy"].edges.min().value}:{dataset._geom.axes["energy"].edges.max().value}'  # noqa: E501
+        meta["DSVAL2"] = (
+            f'{dataset._geom.axes["energy"].edges.min().value}:{dataset._geom.axes["energy"].edges.max().value}'  # noqa: E501
+        )
         meta["DSTYP3"] = "POS(RA,DEC)     "
 
         offset_max = np.max(dataset._geom.width).to_value("deg")
-        meta[
-            "DSVAL3"
-        ] = f"CIRCLE({fixed_icrs.ra.deg},{fixed_icrs.dec.deg},{offset_max})"  # noqa: E501
+        meta["DSVAL3"] = (
+            f"CIRCLE({fixed_icrs.ra.deg},{fixed_icrs.dec.deg},{offset_max})"  # noqa: E501
+        )
         meta["DSUNI3"] = "deg             "
         meta["NDSKEYS"] = " 3 "
 
@@ -584,8 +601,12 @@ class MapDatasetEventSampler:
                 self.event_list_meta(dataset, observation, self.keep_mc_id)
             )
 
+        sort_by_time = np.argsort(events.table["TIME"])
+        events.table = events.table[sort_by_time]
+
         geom = dataset._geom
         selection = geom.contains(events.map_coord(geom))
+        log.info("Event sampling completed.")
         return events.select_row_subset(selection)
 
 
@@ -626,7 +647,7 @@ class ObservationEventSampler(MapDatasetEventSampler):
         n_event_bunch=10000,
         dataset_kwargs=None,
     ):
-        self.dataset_kwargs = dataset_kwargs
+        self.dataset_kwargs = dataset_kwargs or {}
         self.random_state = get_random_state(random_state)
         self.oversample_energy_factor = oversample_energy_factor
         self.t_delta = t_delta
