@@ -12,8 +12,14 @@ from astropy.utils.exceptions import AstropyUserWarning
 from regions import CircleSkyRegion
 import gammapy.irf.psf.map as psf_map_module
 from gammapy.catalog import SourceCatalog3FHL
-from gammapy.data import GTI
-from gammapy.datasets import Datasets, MapDataset, MapDatasetOnOff
+from gammapy.data import GTI, DataStore
+from gammapy.datasets import (
+    Datasets,
+    MapDataset,
+    MapDatasetOnOff,
+    create_empty_map_dataset_from_irfs,
+    create_map_dataset_from_observation,
+)
 from gammapy.datasets.map import RAD_AXIS_DEFAULT
 from gammapy.irf import (
     EDispKernelMap,
@@ -21,6 +27,7 @@ from gammapy.irf import (
     EffectiveAreaTable2D,
     EnergyDependentMultiGaussPSF,
     EnergyDispersion2D,
+    PSFKernel,
     PSFMap,
     RecoPSFMap,
 )
@@ -164,10 +171,10 @@ def get_psf():
 def get_edisp(geom, geom_etrue):
     filename = "$GAMMAPY_DATA/hess-dl3-dr1/data/hess_dl3_dr1_obs_id_020136.fits.gz"
     edisp2d = EnergyDispersion2D.read(filename, hdu="EDISP")
-    energy = geom.axes["energy"].edges
-    energy_true = geom_etrue.axes["energy_true"].edges
+    energy_axis = geom.axes["energy"]
+    energy_axis_true = geom_etrue.axes["energy_true"]
     edisp_kernel = edisp2d.to_edisp_kernel(
-        offset="1.2 deg", energy=energy, energy_true=energy_true
+        offset="1.2 deg", energy_axis=energy_axis, energy_axis_true=energy_axis_true
     )
     edisp = EDispKernelMap.from_edisp_kernel(edisp_kernel)
     return edisp
@@ -201,13 +208,13 @@ def get_map_dataset(geom, geom_etrue, edisp="edispmap", name="test", **kwargs):
     if edisp == "edispmap":
         edisp = EDispMap.from_diagonal_response(energy_axis_true=e_true)
         data = exposure.get_spectrum(geom.center_skydir).data
-        edisp.exposure_map.data = np.repeat(data, 2, axis=-1)
+        edisp.exposure_map.data = np.repeat(np.expand_dims(data, -1), 2, axis=-1)
     elif edisp == "edispkernelmap":
         edisp = EDispKernelMap.from_diagonal_response(
             energy_axis=e_reco, energy_axis_true=e_true
         )
         data = exposure.get_spectrum(geom.center_skydir).data
-        edisp.exposure_map.data = np.repeat(data, 2, axis=-1)
+        edisp.exposure_map.data = np.repeat(np.expand_dims(data, -1), 2, axis=-1)
     else:
         edisp = None
 
@@ -276,7 +283,15 @@ def test_fake(sky_model, geom, geom_etrue):
 
     assert real_dataset.counts.data.shape == dataset.counts.data.shape
     assert_allclose(real_dataset.counts.data.sum(), 9525.299054, rtol=1e-5)
-    assert_allclose(dataset.counts.data.sum(), 9711)
+    assert_allclose(dataset.counts.data.sum(), 9709)
+    assert dataset.counts.data.dtype == float
+
+    stacked = get_map_dataset(geom, geom_etrue)
+    bkg_model = FoVBackgroundModel(dataset_name=stacked.name)
+    stacked.models = [sky_model, bkg_model]
+    stacked.counts = stacked.npred()
+    dataset.stack(stacked)
+    assert_allclose(dataset.counts.data.sum(), 19234.3407, 1e-2)
 
 
 @requires_data()
@@ -738,7 +753,7 @@ def test_prior_stat_sum(sky_model, geom, geom_etrue):
     datasets.models = models
     dataset.counts = dataset.npred()
 
-    uniformprior = UniformPrior(min=-np.inf, max=0, weight=1)
+    uniformprior = UniformPrior(min=0, max=np.inf, weight=1)
     datasets.models.parameters["amplitude"].prior = uniformprior
     assert_allclose(datasets.stat_sum(), 12825.9370, rtol=1e-3)
 
@@ -758,7 +773,6 @@ def test_map_fit_ray(sky_model, geom, geom_etrue):
     dataset_1 = get_map_dataset(geom, geom_etrue, name="test-1")
     dataset_2 = get_map_dataset(geom, geom_etrue, name="test-2")
     datasets = Datasets([dataset_1, dataset_2])
-
     models = Models(datasets.models)
     models.insert(0, sky_model)
 
@@ -772,10 +786,22 @@ def test_map_fit_ray(sky_model, geom, geom_etrue):
     models["test-1-bkg"].spectral_model.norm.value = 0.49
     models["test-2-bkg"].spectral_model.norm.value = 0.99
 
+    datasets.models = None
+
     actors = DatasetsActor(datasets)
+    assert len(actors.models) == 0
+
+    actors.models = models
+    assert len(actors.models) == len(models)
+    assert len(actors.parameters) == len(models.parameters.unique_parameters)
+
+    assert len(actors[0].models) == len(models) - 1
+
     fit = Fit()
     result = fit.run(datasets=actors)
 
+    assert_allclose(result.models.covariance.data, actors.models.covariance.data)
+
     assert result.success
     assert result.optimize_result.backend == "minuit"
 
@@ -942,6 +968,41 @@ def test_create_with_migra(tmp_path):
     assert dataset_new.edisp.edisp_map.data.shape == (3, 50, 10, 10)
 
 
+def test_create_high_dimension():
+    # tests empty datasets created with additional axes
+    label_axis = LabelMapAxis(["a", "b"], name="type")
+    rad_axis = MapAxis(nodes=np.linspace(0.0, 1.0, 51), unit="deg", name="rad")
+    migra_axis = MapAxis(nodes=np.linspace(0.0, 3.0, 51), unit="", name="migra")
+    e_reco = MapAxis.from_edges(
+        np.logspace(-1.0, 1.0, 3), name="energy", unit=u.TeV, interp="log"
+    )
+    e_true = MapAxis.from_edges(
+        np.logspace(-1.0, 1.0, 4), name="energy_true", unit=u.TeV, interp="log"
+    )
+    geom = WcsGeom.create(binsz=0.02, width=(2, 2), axes=[label_axis, e_reco])
+    empty_dataset = MapDataset.create(
+        geom=geom, energy_axis_true=e_true, rad_axis=rad_axis
+    )
+
+    assert empty_dataset.counts.data.shape == (2, 2, 100, 100)
+
+    assert empty_dataset.exposure.data.shape == (2, 3, 100, 100)
+
+    assert empty_dataset.psf.psf_map.data.shape == (2, 3, 50, 10, 10)
+    assert empty_dataset.psf.exposure_map.data.shape == (2, 3, 1, 10, 10)
+
+    assert empty_dataset.edisp.edisp_map.data.shape == (2, 3, 2, 10, 10)
+    assert empty_dataset.edisp.exposure_map.data.shape == (2, 3, 1, 10, 10)
+    assert_allclose(empty_dataset.edisp.edisp_map.data.sum(), 600)
+
+    empty_dataset2 = MapDataset.create(
+        geom=geom, energy_axis_true=e_true, rad_axis=rad_axis, migra_axis=migra_axis
+    )
+
+    assert empty_dataset2.edisp.edisp_map.data.shape == (2, 3, 50, 10, 10)
+    assert empty_dataset2.edisp.exposure_map.data.shape == (2, 3, 1, 10, 10)
+
+
 def test_stack(sky_model):
     axis = MapAxis.from_energy_bounds("0.1 TeV", "10 TeV", nbin=3)
     geom = WcsGeom.create(
@@ -1173,19 +1234,21 @@ def to_cube(image):
     # introduce a fake energy axis for now
     axis = MapAxis.from_edges([1, 10] * u.TeV, name="energy")
     geom = image.geom.to_cube([axis])
-    return WcsNDMap.from_geom(geom=geom, data=image.data)
+    return WcsNDMap.from_geom(geom=geom, data=image.data, unit=image.unit)
 
 
 @pytest.fixture
 def images():
     """Load some `counts`, `counts_off`, `acceptance_on`, `acceptance_off" images"""
     filename = "$GAMMAPY_DATA/tests/unbundled/hess/survey/hess_survey_snippet.fits.gz"
+    exposure_image = WcsNDMap.read(filename, hdu="EXPGAMMAMAP").copy(unit="m2s")
+
     return {
         "counts": to_cube(WcsNDMap.read(filename, hdu="ON")),
         "counts_off": to_cube(WcsNDMap.read(filename, hdu="OFF")),
         "acceptance": to_cube(WcsNDMap.read(filename, hdu="ONEXPOSURE")),
         "acceptance_off": to_cube(WcsNDMap.read(filename, hdu="OFFEXPOSURE")),
-        "exposure": to_cube(WcsNDMap.read(filename, hdu="EXPGAMMAMAP")),
+        "exposure": to_cube(exposure_image),
         "background": to_cube(WcsNDMap.read(filename, hdu="BACKGROUND")),
     }
 
@@ -1411,13 +1474,82 @@ def test_stack_onoff(images):
 
     assert_allclose(stacked.counts.data.sum(), 2 * dataset.counts.data.sum())
     assert_allclose(stacked.counts_off.data.sum(), 2 * dataset.counts_off.data.sum())
-    assert_allclose(
-        stacked.acceptance.data.sum(), dataset.data_shape[1] * dataset.data_shape[2]
-    )
-    assert_allclose(np.nansum(stacked.acceptance_off.data), 2.925793e08, rtol=1e-5)
+    assert_allclose(stacked.acceptance.data, 2 * dataset.acceptance.data)
+    assert_allclose(np.nansum(stacked.acceptance_off.data), 40351192, rtol=1e-5)
     assert_allclose(stacked.exposure.data, 2.0 * dataset.exposure.data)
 
 
+@requires_data()
+def test_stack_onoff_with_masked_input(images):
+    dataset = get_map_dataset_onoff(images)
+    dataset.mask_safe.data[0, 125:, 125:] = False
+    stacked = dataset.copy().to_masked()
+    stacked.stack(dataset)
+
+    assert_allclose(stacked.counts.data.sum(), 8054)
+    assert_allclose(
+        stacked.counts_off.data[0, :125, :125],
+        2 * dataset.counts_off.data[0, :125, :125],
+    )
+    assert_allclose(stacked.counts_off.data[0, 125:, 125:], 0)
+    assert_allclose(
+        stacked.acceptance.data[0, :125, :125],
+        2 * dataset.acceptance.data[0, :125, :125],
+    )
+    assert_allclose(stacked.acceptance.data[0, 125:, 125:], 0)
+    assert_allclose(stacked.acceptance.data.sum(), 7957.8296)
+    assert_allclose(np.nansum(stacked.acceptance_off.data), 37661880.0, rtol=1e-5)
+    assert_allclose(
+        stacked.exposure.data[0, :125, :125], 2.0 * dataset.exposure.data[0, :125, :125]
+    )
+    assert_allclose(stacked.exposure.data[0, 125:, 125:], 0)
+
+
+@requires_data()
+def test_stack_onoff_with_unmasked_input(images):
+    dataset = get_map_dataset_onoff(images)
+    dataset.mask_safe.data[0, 125:, 125:] = False
+    stacked = dataset.copy()
+    stacked.stack(dataset)
+
+    assert_allclose(
+        stacked.counts.data[0, :125, :125], 2 * dataset.counts.data[0, :125, :125]
+    )
+    assert_allclose(
+        stacked.counts.data[0, 125:, 125:], dataset.counts.data[0, 125:, 125:]
+    )
+    assert_allclose(
+        stacked.counts_off.data[0, :125, :125],
+        2 * dataset.counts_off.data[0, :125, :125],
+    )
+    assert_allclose(
+        stacked.counts_off.data[0, 125:, 125:], dataset.counts_off.data[0, 125:, 125:]
+    )
+    assert_allclose(
+        stacked.acceptance.data[0, :125, :125],
+        2 * dataset.acceptance.data[0, :125, :125],
+    )
+    assert_allclose(
+        stacked.acceptance.data[0, 125:, 125:], dataset.acceptance.data[0, 125:, 125:]
+    )
+    assert_allclose(
+        stacked.acceptance_off.data[0, :125, :125],
+        2 * dataset.acceptance_off.data[0, :125, :125],
+        rtol=1e-5,
+    )
+    assert_allclose(
+        stacked.acceptance_off.data[0, 125:, 125:],
+        dataset.acceptance_off.data[0, 125:, 125:],
+        rtol=1e-5,
+    )
+    assert_allclose(
+        stacked.exposure.data[0, :125, :125], 2.0 * dataset.exposure.data[0, :125, :125]
+    )
+    assert_allclose(
+        stacked.exposure.data[0, 125:, 125:], dataset.exposure.data[0, 125:, 125:]
+    )
+
+
 def test_dataset_cutout_aligned(geom):
     dataset = MapDataset.create(geom)
 
@@ -1581,6 +1713,7 @@ def test_map_dataset_on_off_fake(geom):
     assert_allclose(empty_dataset.counts.data[0, 50, 50], 0)
     assert_allclose(empty_dataset.counts.data.mean(), 0.99445, rtol=1e-3)
     assert_allclose(empty_dataset.counts_off.data.mean(), 10.00055, rtol=1e-3)
+    assert empty_dataset.counts.data.dtype == float
 
 
 @requires_data()
@@ -1898,6 +2031,8 @@ def test_dataset_mixed_geom(tmpdir):
     dataset = MapDataset.from_geoms(
         geom=geom, geom_exposure=geom_exposure, geom_psf=geom_psf, geom_edisp=geom_edisp
     )
+    assert isinstance(dataset.psf, PSFMap)
+    assert isinstance(dataset._psf_kernel, PSFKernel)
 
     filename = tmpdir / "test.fits"
     dataset.write(filename)
@@ -1911,6 +2046,33 @@ def test_dataset_mixed_geom(tmpdir):
     assert isinstance(dataset.psf.psf_map.geom.region, CircleSkyRegion)
     assert isinstance(dataset.edisp.edisp_map.geom.region, CircleSkyRegion)
 
+    assert isinstance(dataset.psf, PSFMap)
+    assert dataset.psf.has_single_spatial_bin
+    assert isinstance(dataset._psf_kernel, PSFKernel)
+
+    geom_psf = WcsGeom.create(npix=1, axes=[rad_axis, energy_axis_true])
+    dataset = MapDataset.from_geoms(
+        geom=geom, geom_exposure=geom_exposure, geom_psf=geom_psf, geom_edisp=geom_edisp
+    )
+
+    assert isinstance(dataset.psf, PSFMap)
+    assert dataset.psf.has_single_spatial_bin
+    assert isinstance(dataset._psf_kernel, PSFKernel)
+    psf_1bin = dataset.psf.copy()
+
+    geom_psf = WcsGeom.create(npix=3, axes=[rad_axis, energy_axis_true])
+    dataset = MapDataset.from_geoms(
+        geom=geom, geom_exposure=geom_exposure, geom_psf=geom_psf, geom_edisp=geom_edisp
+    )
+
+    assert isinstance(dataset.psf, PSFMap)
+    assert not dataset.psf.has_single_spatial_bin
+    assert dataset._psf_kernel is None
+
+    dataset.psf.psf_map = psf_1bin.psf_map
+    assert dataset.psf.has_single_spatial_bin
+    assert isinstance(dataset._psf_kernel, PSFKernel)
+
     geom_psf_reco = RegionGeom.create(
         "icrs;circle(0, 0, 0.2)", axes=[rad_axis, energy_axis]
     )
@@ -2060,3 +2222,66 @@ def test_to_masked():
     )
     d1 = datasetonoff.to_masked()
     assert_allclose(d1.counts.data.sum(), 170)
+
+
+def test_get_psf_kernel_multiscale():
+    energy_axis = MapAxis.from_edges(
+        np.logspace(-1.0, 1.0, 4), unit="TeV", name="energy_true"
+    )
+    geom = WcsGeom.create(binsz=0.02 * u.deg, width=4.0 * u.deg, axes=[energy_axis])
+
+    psf = PSFMap.from_gauss(energy_axis, sigma=[0.1, 0.2, 0.3] * u.deg)
+
+    kernel = psf.get_psf_kernel(geom=geom, max_radius="3 deg")
+    assert_allclose(kernel.psf_kernel_map.geom.width, 2 * 3 * u.deg, atol=0.02)
+
+    kernel = psf.get_psf_kernel(geom=geom, max_radius=None)
+
+    geom_image = kernel.psf_kernel_map.geom.to_image()
+    coords = geom_image.get_coord()
+    sep = coords.skycoord.separation(geom_image.center_skydir)
+
+    widths = [0.74, 1.34, 1.34] * u.deg
+    for im, width in zip(kernel.psf_kernel_map.iter_by_image(), widths):
+        mask = sep > width
+        assert np.all(im.data[mask] == 0)
+        assert np.any(im.data[~mask] > 0)
+
+
+@requires_data()
+def test_create_map_dataset_from_observation():
+    datastore = DataStore.from_dir("$GAMMAPY_DATA/hess-dl3-dr1/")
+    observations = datastore.get_observations()
+    dataset_new = create_map_dataset_from_observation(observations[0])
+
+    assert dataset_new.counts.data.sum() == 0
+    assert_allclose(dataset_new.exposure.data.sum(), 43239974121207.85)
+
+
+@requires_data()
+def test_create_empty_map_dataset_from_irfs(geom, geom_etrue):
+    datastore = DataStore.from_dir("$GAMMAPY_DATA/hess-dl3-dr1/")
+    obs = datastore.get_observations()[0]
+
+    dataset_new = create_empty_map_dataset_from_irfs(obs)
+
+    assert dataset_new.counts.data.sum() == 0
+    assert dataset_new.exposure.data.sum() == 0
+
+    dataset = get_map_dataset(geom, geom_etrue)
+    obs.psf = dataset.psf
+    obs.edisp = dataset.edisp
+
+    dataset_new = create_empty_map_dataset_from_irfs(obs)
+
+    assert dataset_new.counts.data.sum() == 0
+    assert dataset_new.exposure.data.sum() == 0
+
+    obs.edisp = dataset.edisp.to_edisp_kernel_map(
+        dataset.background.geom.axes["energy"]
+    )
+
+    dataset_new = create_empty_map_dataset_from_irfs(obs)
+
+    assert dataset_new.counts.data.sum() == 0
+    assert dataset_new.exposure.data.sum() == 0
