@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import logging
+from copy import deepcopy
 import numpy as np
 from astropy import units as u
 from astropy.io import fits
@@ -75,13 +76,17 @@ VALID_QUANTITIES = [
     "npred",
     "npred_excess",
     "stat",
-    "stat_scan",
     "stat_null",
+    "stat_scan",
+    "dnde_scan_values",
     "niter",
     "is_ul",
     "counts",
     "success",
     "n_dof",
+    "alpha",
+    "acceptance_on",
+    "acceptance_off",
 ]
 
 
@@ -92,6 +97,8 @@ OPTIONAL_QUANTITIES_COMMON = [
     "npred_excess",
     "stat",
     "stat_null",
+    "stat_scan",
+    "dnde_scan_values",
     "niter",
     "is_ul",
     "counts",
@@ -134,6 +141,9 @@ class FluxMaps:
         * sqrt_ts : optional, the square root of the test statistic, when relevant.
         * success : optional, a boolean tagging the validity of the estimation.
         * n_dof : optional, the number of degrees of freedom used in TS computation
+        * alpha : optional, normalisation factor to accounts for differences between the test region and the background
+        * acceptance_off : optional, acceptance from the off region
+        * acceptance_on : optional, acceptance from the on region
 
     reference_model : `~gammapy.modeling.models.SkyModel`, optional
         The reference model to use for conversions. If None, a model consisting
@@ -176,7 +186,7 @@ class FluxMaps:
 
     @property
     def available_quantities(self):
-        """Available quantities"""
+        """Available quantities."""
         return list(self._data.keys())
 
     @staticmethod
@@ -218,8 +228,9 @@ class FluxMaps:
         if not required.issubset(keys):
             missing = required.difference(keys)
             raise ValueError(
-                "Missing data / column for SED type '{}':"
-                " {}".format(sed_type, missing)
+                "Missing data / column for SED type '{}':" " {}".format(
+                    sed_type, missing
+                )
             )
 
     # TODO: add support for scan
@@ -332,7 +343,7 @@ class FluxMaps:
 
     @property
     def reference_spectral_model(self):
-        """Reference spectral model as a `SpectralModel`"""
+        """Reference spectral model as a `SpectralModel`."""
         return self.reference_model.spectral_model
 
     @property
@@ -487,6 +498,12 @@ class FluxMaps:
         self._check_quantity("stat_scan")
         return self._data["stat_scan"]
 
+    @property
+    def dnde_scan_values(self):
+        """Fit statistic norm scan values."""
+        self._check_quantity("dnde_scan_values")
+        return self._data["dnde_scan_values"]
+
     @property
     def stat(self):
         """Fit statistic value."""
@@ -507,7 +524,7 @@ class FluxMaps:
 
     @property
     def ts_scan(self):
-        """Test statistic scan as a `~gammapy.maps.Map` object"""
+        """Test statistic scan as a `~gammapy.maps.Map` object."""
         return self.stat_scan - np.expand_dims(self.stat.data, 2)
 
     # TODO: always derive sqrt(TS) from TS?
@@ -578,6 +595,24 @@ class FluxMaps:
         self._check_quantity("n_dof")
         return self._data["n_dof"]
 
+    @property
+    def alpha(self):
+        """The normalisation, alpha, for differences between the on and off regions."""
+        self._check_quantity("alpha")
+        return self._data["alpha"]
+
+    @property
+    def acceptance_on(self):
+        """The acceptance in the on region."""
+        self._check_quantity("acceptance_on")
+        return self._data["acceptance_on"]
+
+    @property
+    def acceptance_off(self):
+        """The acceptance in the off region."""
+        self._check_quantity("acceptance_off")
+        return self._data["acceptance_off"]
+
     @property
     def dnde_ref(self):
         """Reference differential flux."""
@@ -858,7 +893,6 @@ class FluxMaps:
             FluxMap iteration.
 
         """
-
         split_maps = {}
         axis = self.geom.axes[axis_name]
         gti = self.gti
@@ -1093,13 +1127,37 @@ class FluxMaps:
         ) as hdulist:
             return cls.from_hdulist(hdulist, checksum=checksum)
 
+    def copy(self, reference_model=None):
+        """Deep copy.
+
+        Parameters
+        ----------
+        reference_model : `~gammapy.modeling.models.SkyModel`, optional
+            The reference model to use for conversions. If None, the original model is copied.
+            Flux maps have been obtained for a specific reference model.
+            Changing it will change the fluxes. Handle with care.
+
+        Returns
+        -------
+        flux_maps : `~gammapy.estimators.FluxMaps`
+            Copied flux maps object.
+
+        """
+        new = deepcopy(self)
+        if reference_model is not None:
+            new._reference_model = reference_model.copy()
+            log.warning(
+                "Changing the reference model will change the fluxes. Handle with care."
+            )
+        return new
+
     def slice_by_idx(self, slices):
         """Slice flux maps by index.
 
         Parameters
         ----------
         slices : dict
-            Dict of axes names and integers or `slice` object pairs. Contains one
+            Dictionary of axes names and integers or `slice` object pairs. Contains one
             element for each non-spatial dimension. For integer indexing the
             corresponding axes is dropped from the map. Axes not specified in the
             dict are kept unchanged.
@@ -1108,8 +1166,15 @@ class FluxMaps:
         -------
         flux_maps : `FluxMaps`
             Sliced flux maps object.
-        """
 
+        Examples
+        --------
+        >>> from gammapy.estimators import FluxPoints
+        >>> import astropy.units as u
+        >>> fp = FluxPoints.read("$GAMMAPY_DATA/estimators/crab_hess_fp/crab_hess_fp.fits")
+        >>> slices = {"energy": slice(0, 2)}
+        >>> sliced = fp.slice_by_idx(slices)
+        """
         data = {}
 
         for key, item in self._data.items():
@@ -1123,12 +1188,12 @@ class FluxMaps:
         )
 
     def slice_by_coord(self, slices):
-        """Slice flux maps by coordinate values
+        """Slice flux maps by coordinate values.
 
         Parameters
         ----------
         slices : dict
-            Dict of axes names and `astropy.Quantity` or `astropy.Time` or `slice` object pairs.
+            Dictionary of axes names and `astropy.Quantity` or `astropy.Time` or `slice` object pairs.
             Contains one element for each non-spatial dimension. For integer indexing the
             corresponding axes is dropped from the map. Axes not specified in the
             dict are kept unchanged.
@@ -1138,8 +1203,15 @@ class FluxMaps:
         -------
         flux_maps : `FluxMaps`
             Sliced flux maps object.
-        """
 
+        Examples
+        --------
+        >>> from gammapy.estimators import FluxPoints
+        >>> import astropy.units as u
+        >>> lc_1d = FluxPoints.read("$GAMMAPY_DATA/estimators/pks2155_hess_lc/pks2155_hess_lc.fits")
+        >>> slices = {"time": slice(2035.93*u.day, 2036.05*u.day)}
+        >>> sliced = lc_1d.slice_by_coord(slices)
+        """
         idx_intervals = []
 
         for key, interval in zip(slices.keys(), slices.values()):
@@ -1168,8 +1240,14 @@ class FluxMaps:
         -------
         flux_maps : `FluxMaps`
             Sliced flux maps object.
-        """
 
+        Examples
+        --------
+        >>> from gammapy.estimators import FluxPoints
+        >>> import astropy.units as u
+        >>> lc_1d = FluxPoints.read("$GAMMAPY_DATA/estimators/pks2155_hess_lc/pks2155_hess_lc.fits")
+        >>> sliced = lc_1d.slice_by_time(time_min=2035.93*u.day, time_max=2036.05*u.day)
+        """
         time_slice = slice(time_min, time_max)
 
         return self.slice_by_coord({"time": time_slice})
@@ -1186,8 +1264,14 @@ class FluxMaps:
         -------
         flux_maps : `FluxMaps`
             Sliced flux maps object.
-        """
 
+        Examples
+        --------
+        >>> from gammapy.estimators import FluxPoints
+        >>> import astropy.units as u
+        >>> fp = FluxPoints.read("$GAMMAPY_DATA/estimators/crab_hess_fp/crab_hess_fp.fits")
+        >>> sliced = fp.slice_by_energy(energy_min=2*u.TeV, energy_max=10*u.TeV)
+        """
         energy_slice = slice(energy_min, energy_max)
 
         return self.slice_by_coord({"energy": energy_slice})
