@@ -12,15 +12,13 @@ from ..core import Estimator
 from ..utils import estimate_exposure_reco_energy
 from .core import FluxMaps
 
-__all__ = [
-    "ExcessMapEstimator",
-]
+__all__ = ["ExcessMapEstimator"]
 
 log = logging.getLogger(__name__)
 
 
-def convolved_map_dataset_counts_statistics(dataset, kernel, mask, correlate_off):
-    """Return a `CountsStatistic` object.
+def _get_convolved_maps(dataset, kernel, mask, correlate_off):
+    """Return convolved maps.
 
     Parameters
     ----------
@@ -35,8 +33,8 @@ def convolved_map_dataset_counts_statistics(dataset, kernel, mask, correlate_off
 
     Returns
     -------
-    counts_statistic : `~gammapy.stats.CashCountsStatistic` or `~gammapy.stats.WStatCountsStatistic`
-        The counts statistic.
+    convolved_maps : dict
+        Dictionary of convolved maps.
     """
     # Kernel is modified later make a copy here
     kernel = copy.deepcopy(kernel)
@@ -47,19 +45,20 @@ def convolved_map_dataset_counts_statistics(dataset, kernel, mask, correlate_off
     n_on = dataset.counts * mask
     n_on_conv = np.rint(n_on.convolve(kernel_data).data)
 
+    convolved_maps = {"n_on_conv": n_on_conv}
+
     if isinstance(dataset, MapDatasetOnOff):
         n_off = dataset.counts_off * mask
         npred_sig = dataset.npred_signal() * mask
         acceptance_on = dataset.acceptance * mask
         acceptance_off = dataset.acceptance_off * mask
-
         npred_sig_convolve = npred_sig.convolve(kernel_data)
         if correlate_off:
             background = dataset.background * mask
             background.data[dataset.acceptance_off == 0] = 0.0
             background_conv = background.convolve(kernel_data)
-
             n_off = n_off.convolve(kernel_data)
+
             with np.errstate(invalid="ignore", divide="ignore"):
                 alpha = background_conv / n_off
 
@@ -68,13 +67,54 @@ def convolved_map_dataset_counts_statistics(dataset, kernel, mask, correlate_off
 
             with np.errstate(invalid="ignore", divide="ignore"):
                 alpha = acceptance_on_convolve / acceptance_off
-
-        return WStatCountsStatistic(
-            n_on_conv.data, n_off.data, alpha.data, npred_sig_convolve.data
+        convolved_maps.update(
+            {
+                "n_off": n_off,
+                "npred_sig_convolve": npred_sig_convolve,
+                "acceptance_on": acceptance_on,
+                "acceptance_off": acceptance_off,
+                "alpha": alpha,
+            }
         )
     else:
         npred = dataset.npred() * mask
         background_conv = npred.convolve(kernel_data)
+        convolved_maps.update(
+            {
+                "background_conv": background_conv,
+            }
+        )
+
+    return convolved_maps
+
+
+def convolved_map_dataset_counts_statistics(convolved_maps, stat_type):
+    """Return a `CountsStatistic` object.
+
+    Parameters
+    ----------
+    convolved_maps : dict
+        Dictionary of convolved maps.
+    stat_type : str
+        The statistic type, either 'wstat' or 'cash'.
+
+    Returns
+    -------
+    counts_statistic : `~gammapy.stats.CashCountsStatistic` or `~gammapy.stats.WStatCountsStatistic`
+        The counts statistic.
+    """
+    if stat_type == "wstat":
+        n_on_conv = convolved_maps["n_on_conv"]
+        n_off = convolved_maps["n_off"]
+        alpha = convolved_maps["alpha"]
+        npred_sig_convolve = convolved_maps["npred_sig_convolve"]
+
+        return WStatCountsStatistic(
+            n_on_conv.data, n_off.data, alpha.data, npred_sig_convolve.data
+        )
+    elif stat_type == "cash":
+        n_on_conv = convolved_maps["n_on_conv"]
+        background_conv = convolved_maps["background_conv"]
         return CashCountsStatistic(n_on_conv.data, background_conv.data)
 
 
@@ -86,7 +126,7 @@ class ExcessMapEstimator(Estimator):
 
     .. note::
 
-        By default the excess estimator correlates the off counts as well to avoid
+        By default, the excess estimator correlates the off counts as well to avoid
         artifacts at the edges of the :term:`FoV` for stacked on-off datasets.
         However, when the on-off dataset has been derived from a ring background
         estimate, this leads to the off counts being correlated twice. To avoid
@@ -96,7 +136,7 @@ class ExcessMapEstimator(Estimator):
 
     Parameters
     ----------
-    correlation_radius : `~astropy.coordinate.Angle`
+    correlation_radius : `~astropy.coordinates.Angle`
         Correlation radius to use.
     n_sigma : float
         Confidence level for the asymmetric errors expressed in number of sigma.
@@ -115,12 +155,17 @@ class ExcessMapEstimator(Estimator):
         Which additional maps to estimate besides delta TS, significance and symmetric error.
         Available options are:
 
-            * "all": all the optional steps are executed
+            * "all": all the optional steps are executed.
             * "errn-errp": estimate asymmetric errors.
             * "ul": estimate upper limits.
-            * "sensitivity": estimate sensitivity for a given significance
+            * "sensitivity": estimate sensitivity for a given significance.
+            * "alpha": normalisation factor to accounts for differences between the on and off regions.
+            * "acceptance_on": acceptance from the on region.
+            * "acceptance_off": acceptange from the off region.
 
         Default is None so the optional steps are not executed.
+        Note: "alpha", "acceptance_on" and "acceptance_off" can only be selected if the dataset is a
+        `~gammapy.datasets.MapDatasetOnOff`.
     energy_edges : list of `~astropy.units.Quantity`, optional
         Edges of the target maps energy bins. The resulting bin edges won't be exactly equal to the input ones,
         but rather the closest values to the energy axis edges of the parent dataset.
@@ -130,7 +175,12 @@ class ExcessMapEstimator(Estimator):
         Correlate OFF events. Default is True.
     spectral_model : `~gammapy.modeling.models.SpectralModel`
         Spectral model used for the computation of the flux map.
-        If None, a Power Law of index 2 is assumed (default).
+        If None, a `~gammapy.modeling.models.PowerLawSpectralModel` of index 2 is assumed (default).
+    sum_over_energy_groups : bool
+        Only used if ``energy_edges`` is None.
+        If False, apply the estimator in each energy bin of the parent dataset.
+        If True, apply the estimator in only one bin defined by the energy edges of the parent dataset.
+        Default is False.
 
     Examples
     --------
@@ -145,7 +195,7 @@ class ExcessMapEstimator(Estimator):
     <BLANKLINE>
       geom                   : WcsGeom
       axes                   : ['lon', 'lat', 'energy']
-      shape                  : (320, 240, 1)
+      shape                  : (np.int64(320), np.int64(240), 1)
       quantities             : ['npred', 'npred_excess', 'counts', 'ts', 'sqrt_ts', 'norm', 'norm_err']
       ref. model             : pl
       n_sigma                : 1
@@ -156,7 +206,14 @@ class ExcessMapEstimator(Estimator):
     """
 
     tag = "ExcessMapEstimator"
-    _available_selection_optional = ["errn-errp", "ul", "sensitivity"]
+    _available_selection_optional = [
+        "errn-errp",
+        "ul",
+        "sensitivity",
+        "alpha",
+        "acceptance_on",
+        "acceptance_off",
+    ]
 
     def __init__(
         self,
@@ -171,6 +228,7 @@ class ExcessMapEstimator(Estimator):
         gamma_min_sensitivity=10,
         bkg_syst_fraction_sensitivity=0.05,
         apply_threshold_sensitivity=False,
+        sum_over_energy_groups=False,
     ):
         self.correlation_radius = correlation_radius
         self.n_sigma = n_sigma
@@ -181,6 +239,7 @@ class ExcessMapEstimator(Estimator):
         self.apply_threshold_sensitivity = apply_threshold_sensitivity
         self.selection_optional = selection_optional
         self.energy_edges = energy_edges
+        self.sum_over_energy_groups = sum_over_energy_groups
         self.correlate_off = correlate_off
 
         if spectral_model is None:
@@ -198,7 +257,7 @@ class ExcessMapEstimator(Estimator):
         self._correlation_radius = Angle(correlation_radius)
 
     def run(self, dataset):
-        """Compute correlated excess, Li & Ma significance and flux maps
+        """Compute correlated excess, Li & Ma significance and flux maps.
 
         If a model is set on the dataset the excess map estimator will compute
         the excess taking into account the predicted counts of the model.
@@ -223,6 +282,17 @@ class ExcessMapEstimator(Estimator):
         resampled_dataset = dataset.resample_energy_axis(
             energy_axis=axis, name=dataset.name
         )
+
+        if dataset.exposure:
+            reco_exposure = estimate_exposure_reco_energy(
+                dataset, self.spectral_model, normalize=False
+            )
+            reco_exposure = reco_exposure.resample_axis(
+                axis=axis, weights=dataset.mask_safe
+            )
+        else:
+            reco_exposure = None
+
         if isinstance(dataset, MapDatasetOnOff):
             resampled_dataset.models = dataset.models
         else:
@@ -231,7 +301,7 @@ class ExcessMapEstimator(Estimator):
             )
             resampled_dataset.models = None
 
-        result = self.estimate_excess_map(resampled_dataset)
+        result = self.estimate_excess_map(resampled_dataset, reco_exposure)
         return result
 
     def estimate_kernel(self, dataset):
@@ -247,7 +317,6 @@ class ExcessMapEstimator(Estimator):
         kernel : `~astropy.convolution.Tophat2DKernel`
             Kernel.
         """
-
         pixel_size = np.mean(np.abs(dataset.counts.geom.wcs.wcs.cdelt))
         size = self.correlation_radius.deg / pixel_size
         kernel = Tophat2DKernel(size)
@@ -278,9 +347,8 @@ class ExcessMapEstimator(Estimator):
             mask = Map.from_geom(dataset.counts.geom, data=True, dtype=bool)
         return mask
 
-    def estimate_exposure_reco_energy(self, dataset, kernel, mask):
-        """Estimate exposure map in reconstructed energy for a single dataset
-           assuming the given spectral_model shape.
+    def estimate_exposure_reco_energy(self, dataset, kernel, mask, reco_exposure):
+        """Estimate exposure map in reconstructed energy for a single dataset assuming the given spectral_model shape.
 
         Parameters
         ----------
@@ -293,22 +361,20 @@ class ExcessMapEstimator(Estimator):
 
         Returns
         -------
-        reco_exposure : `Map`
+        reco_exposure : `~gammapy.maps.Map`
             Reconstructed exposure map.
         """
         if dataset.exposure:
-            reco_exposure = estimate_exposure_reco_energy(
-                dataset, self.spectral_model, normalize=False
-            )
             with np.errstate(invalid="ignore", divide="ignore"):
                 reco_exposure = reco_exposure.convolve(kernel.data) / mask.convolve(
                     kernel.data
                 )
         else:
             reco_exposure = 1
+
         return reco_exposure
 
-    def estimate_excess_map(self, dataset):
+    def estimate_excess_map(self, dataset, reco_exposure):
         """Estimate excess and test statistic maps for a single dataset.
 
         If exposure is defined, a flux map is also computed.
@@ -318,15 +384,13 @@ class ExcessMapEstimator(Estimator):
         dataset : `~gammapy.datasets.MapDataset`
             Map dataset.
         """
-
         kernel = self.estimate_kernel(dataset)
-
         geom = dataset.counts.geom
-
         mask = self.estimate_mask_default(dataset)
 
+        convolved_maps = _get_convolved_maps(dataset, kernel, mask, self.correlate_off)
         counts_stat = convolved_map_dataset_counts_statistics(
-            dataset, kernel, mask, self.correlate_off
+            convolved_maps=convolved_maps, stat_type=dataset.stat_type
         )
 
         maps = {}
@@ -337,7 +401,9 @@ class ExcessMapEstimator(Estimator):
         maps["ts"] = Map.from_geom(geom, data=counts_stat.ts)
         maps["sqrt_ts"] = Map.from_geom(geom, data=counts_stat.sqrt_ts)
 
-        reco_exposure = self.estimate_exposure_reco_energy(dataset, kernel, mask)
+        reco_exposure = self.estimate_exposure_reco_energy(
+            dataset, kernel, mask, reco_exposure
+        )
 
         with np.errstate(invalid="ignore", divide="ignore"):
             maps["norm"] = maps["npred_excess"] / reco_exposure
@@ -380,6 +446,10 @@ class ExcessMapEstimator(Estimator):
                     )
                 excess = Map.from_geom(geom=geom, data=excess_counts)
                 maps["norm_sensitivity"] = excess / reco_exposure
+            if isinstance(dataset, MapDatasetOnOff):
+                keys_onoff = set(["alpha", "acceptance_on", "acceptance_off"])
+                for key in keys_onoff.intersection(self.selection_optional):
+                    maps[key] = convolved_maps[key]
 
         # return nan values outside mask
         for name in maps:
