@@ -1,11 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-import logging
 import numpy as np
 from astropy.table import Column, Table
 from gammapy.maps import Map
 from gammapy.modeling.models import PowerLawSpectralModel, SkyModel
 from gammapy.stats import WStatCountsStatistic
 from ..core import Estimator
+from gammapy.utils.deprecation import deprecated_renamed_argument
 
 __all__ = ["SensitivityEstimator"]
 
@@ -21,8 +21,8 @@ class SensitivityEstimator(Estimator):
 
     Parameters
     ----------
-    spectrum : `SpectralModel`
-        Spectral model assumption. Default is Power Law with index 2.
+    spectral_model : `~gammapy.modeling.models.SpectralModel`, optional
+        Spectral model assumption. Default is power-law with spectral index of 2.
     n_sigma : float, optional
         Minimum significance. Default is 5.
     gamma_min : float, optional
@@ -38,18 +38,20 @@ class SensitivityEstimator(Estimator):
 
     tag = "SensitivityEstimator"
 
+    @deprecated_renamed_argument("spectrum", "spectral_model", "v1.3")
     def __init__(
         self,
-        spectrum=None,
+        spectral_model=None,
         n_sigma=5.0,
         gamma_min=10,
         bkg_syst_fraction=0.05,
     ):
+        if spectral_model is None:
+            spectral_model = PowerLawSpectralModel(
+                index=2, amplitude="1 cm-2 s-1 TeV-1"
+            )
 
-        if spectrum is None:
-            spectrum = PowerLawSpectralModel(index=2, amplitude="1 cm-2 s-1 TeV-1")
-
-        self.spectrum = spectrum
+        self.spectral_model = spectral_model
         self.n_sigma = n_sigma
         self.gamma_min = gamma_min
         self.bkg_syst_fraction = bkg_syst_fraction
@@ -101,12 +103,12 @@ class SensitivityEstimator(Estimator):
         """
         energy = dataset._geom.axes["energy"].center
 
-        dataset.models = SkyModel(spectral_model=self.spectrum)
+        dataset.models = SkyModel(spectral_model=self.spectral_model)
         npred = dataset.npred_signal()
 
         phi_0 = excess / npred
 
-        dnde_model = self.spectrum(energy=energy)
+        dnde_model = self.spectral_model(energy=energy)
         dnde = phi_0.data[:, 0, 0] * dnde_model * energy**2
         return dnde.to("erg / (cm2 s)")
 
@@ -116,9 +118,9 @@ class SensitivityEstimator(Estimator):
         criterion = np.chararray(excess.shape, itemsize=12)
         criterion[is_gamma_limited] = "gamma"
         criterion[is_bkg_syst_limited] = "bkg"
-        criterion[
-            ~np.logical_or(is_gamma_limited, is_bkg_syst_limited)
-        ] = "significance"
+        criterion[~np.logical_or(is_gamma_limited, is_bkg_syst_limited)] = (
+            "significance"
+        )
         return criterion
 
     def run(self, dataset):
@@ -140,18 +142,9 @@ class SensitivityEstimator(Estimator):
         criterion = self._get_criterion(
             excess.data.squeeze(), dataset.background.data.squeeze()
         )
-        logging.warning(
-            "Table column name energy will be deprecated by e_ref since v1.2"
-        )
 
         return Table(
             [
-                Column(
-                    data=energy,
-                    name="energy",
-                    format="5g",
-                    description="Reconstructed Energy",
-                ),
                 Column(
                     data=energy,
                     name="e_ref",
