@@ -17,6 +17,7 @@ from gammapy.utils.regions import (
     make_orthogonal_rectangle_sky_regions,
 )
 from gammapy.utils.testing import requires_data, requires_dependency
+from gammapy.utils.deprecation import GammapyDeprecationWarning
 
 
 def get_simple_dataset_on_off():
@@ -54,6 +55,13 @@ def test_profile_content():
     wcs = mapdataset_onoff.counts.geom.wcs
     boxes = make_horizontal_boxes(wcs)
 
+    with pytest.warns(GammapyDeprecationWarning):
+        FluxProfileEstimator(
+            regions=boxes,
+            energy_edges=[0.1, 1, 10] * u.TeV,
+            spectrum=PowerLawSpectralModel(),
+        )
+
     prof_maker = FluxProfileEstimator(
         regions=boxes,
         energy_edges=[0.1, 1, 10] * u.TeV,
@@ -61,6 +69,7 @@ def test_profile_content():
         n_sigma=1,
         n_sigma_ul=3,
     )
+
     result = prof_maker.run(mapdataset_onoff)
 
     imp_prof = result.to_table(sed_type="flux")
