@@ -7,7 +7,12 @@ from astropy.coordinates import EarthLocation, SkyCoord
 from astropy.table import Table
 from gammapy.data import Observation
 from gammapy.data.pointing import FixedPointingInfo
-from gammapy.datasets import FluxPointsDataset, MapDataset, SpectrumDatasetOnOff
+from gammapy.datasets import (
+    Datasets,
+    FluxPointsDataset,
+    MapDataset,
+    SpectrumDatasetOnOff,
+)
 from gammapy.datasets.spectrum import SpectrumDataset
 from gammapy.estimators import FluxPoints, FluxPointsEstimator
 from gammapy.irf import EDispKernelMap, EffectiveAreaTable2D, load_irf_dict_from_file
@@ -32,8 +37,6 @@ from gammapy.utils.testing import requires_data, requires_dependency
 
 @pytest.fixture()
 def fermi_datasets():
-    from gammapy.datasets import Datasets
-
     filename = "$GAMMAPY_DATA/fermi-3fhl-crab/Fermi-LAT-3FHL_datasets.yaml"
     filename_models = "$GAMMAPY_DATA/fermi-3fhl-crab/Fermi-LAT-3FHL_models.yaml"
     return Datasets.read(filename=filename, filename_models=filename_models)
@@ -167,6 +170,27 @@ def fpe_map_pwl():
     return datasets, fpe
 
 
+@pytest.fixture(scope="session")
+def fpe_map_pwl_ray():
+    """duplicate of fpe_map_pwl to avoid fails due to execution order"""
+    dataset_1 = simulate_map_dataset(name="test-map-pwl")
+    dataset_2 = dataset_1.copy(name="test-map-pwl-2")
+    dataset_2.models = dataset_1.models
+
+    dataset_2.mask_safe = RegionNDMap.from_geom(dataset_2.counts.geom, dtype=bool)
+
+    energy_edges = [0.1, 1, 10, 100] * u.TeV
+    datasets = [dataset_1, dataset_2]
+    fpe = FluxPointsEstimator(
+        energy_edges=energy_edges,
+        source="source",
+        selection_optional="all",
+    )
+    fpe.norm.scan_n_values = 3
+
+    return datasets, fpe
+
+
 @pytest.fixture(scope="session")
 def fpe_map_pwl_reoptimize():
     dataset = simulate_map_dataset()
@@ -288,6 +312,15 @@ def test_run_pwl(fpe_pwl, tmpdir):
     fp_new = FluxPoints.read(tmpdir / "test.fits")
     assert fp_new.meta["sed_type_init"] == "likelihood"
 
+    # test datasets stat
+    fp_dataset = FluxPointsDataset(data=fp, models=fp.reference_model)
+    fp_dataset.stat_type = "chi2"
+    assert_allclose(fp_dataset.stat_sum(), 3.82374, rtol=1e-4)
+    fp_dataset.stat_type = "profile"
+    assert_allclose(fp_dataset.stat_sum(), 3.790053, rtol=1e-4)
+    fp_dataset.stat_type = "distrib"
+    assert_allclose(fp_dataset.stat_sum(), 3.783325, rtol=1e-4)
+
 
 def test_run_ecpl(fpe_ecpl, tmpdir):
     datasets, fpe = fpe_ecpl
@@ -400,6 +433,31 @@ def test_run_map_pwl_reoptimize(fpe_map_pwl_reoptimize):
     assert_allclose(actual, [9.788123, 0.486066, 17.603708], rtol=1e-2)
 
 
+def test_run_no_edip(fpe_pwl, tmpdir):
+    datasets, fpe = fpe_pwl
+
+    datasets = datasets.copy()
+
+    datasets[0].models["source"].apply_irf["edisp"] = False
+    fp = fpe.run(datasets)
+    table = fp.to_table()
+    actual = table["norm"].data
+    assert_allclose(actual, [1.081434, 0.91077, 0.922176], rtol=1e-3)
+
+    datasets[0].edisp = None
+
+    fp = fpe.run(datasets)
+    table = fp.to_table()
+    actual = table["norm"].data
+    assert_allclose(actual, [1.081434, 0.91077, 0.922176], rtol=1e-3)
+
+    datasets[0].models["source"].apply_irf["edisp"] = True
+    fp = fpe.run(datasets)
+    table = fp.to_table()
+    actual = table["norm"].data
+    assert_allclose(actual, [1.081434, 0.91077, 0.922176], rtol=1e-3)
+
+
 @requires_dependency("iminuit")
 @requires_data()
 def test_run_template_npred(fpe_map_pwl, tmpdir):
@@ -636,10 +694,10 @@ def test_flux_points_parallel_ray_actor_spectrum(fpe_pwl):
 
 @requires_data()
 @requires_dependency("ray")
-def test_flux_points_parallel_ray_actor_map(fpe_map_pwl):
+def test_flux_points_parallel_ray_actor_map(fpe_map_pwl_ray):
     from gammapy.datasets.actors import DatasetsActor
 
-    datasets, fpe = fpe_map_pwl
+    datasets, fpe = fpe_map_pwl_ray
     actors = DatasetsActor(datasets)
 
     fp = fpe.run(actors)
@@ -756,3 +814,42 @@ def test_flux_points_estimator_norm_spectral_model(fermi_datasets):
     flux_points_dataset = FluxPointsDataset(data=flux_points, models=model)
     flux_pred = flux_points_dataset.flux_pred()
     assert_allclose(flux_pred, flux_pred_ref, rtol=2e-4)
+
+
+@requires_data()
+def test_fpe_diff_lengths():
+    dataset = SpectrumDatasetOnOff.read(
+        "$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs23523.fits"
+    )
+    dataset1 = SpectrumDatasetOnOff.read(
+        "$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs23559.fits"
+    )
+
+    dataset.meta_table = Table(names=["NAME", "TELESCOP"], data=[["23523"], ["hess"]])
+    dataset1.meta_table = Table(names=["NAME", "TELESCOP"], data=[["23559"], ["hess"]])
+    dataset2 = Datasets([dataset, dataset1]).stack_reduce(name="dataset2")
+
+    dataset3 = dataset1.copy()
+    dataset3.meta_table = None
+
+    pwl = PowerLawSpectralModel()
+
+    datasets = Datasets([dataset1, dataset2, dataset3])
+
+    datasets.models = SkyModel(spectral_model=pwl, name="test")
+    energy_edges = [1, 2, 4, 10] * u.TeV
+    fpe = FluxPointsEstimator(energy_edges=energy_edges, source="test")
+
+    fp = fpe.run(datasets)
+
+    assert_allclose(
+        fp.dnde.data,
+        [[[2.034323e-11]], [[3.39049716e-12]], [[2.96231326e-13]]],
+        rtol=1e-3,
+    )
+
+    dataset4 = dataset1.copy()
+    dataset4.meta_table = Table(names=["NAME", "TELESCOP"], data=[["23523"], ["not"]])
+    datasets = Datasets([dataset1, dataset2, dataset3, dataset4])
+    with pytest.raises(ValueError):
+        fp = fpe.run(datasets)
