@@ -5,6 +5,8 @@ from gammapy.datasets import SpectrumDataset, SpectrumDatasetOnOff
 from gammapy.estimators import FluxPoints, SensitivityEstimator
 from gammapy.irf import EDispKernelMap
 from gammapy.maps import MapAxis, RegionNDMap
+from gammapy.modeling.models import PowerLawSpectralModel
+from gammapy.utils.deprecation import GammapyDeprecationWarning
 
 
 @pytest.fixture()
@@ -37,19 +39,16 @@ def test_cta_sensitivity_estimator(spectrum_dataset, caplog):
         acceptance=RegionNDMap.from_geom(geom=geom, data=1),
         acceptance_off=RegionNDMap.from_geom(geom=geom, data=5),
     )
+    with pytest.warns(GammapyDeprecationWarning):
+        SensitivityEstimator(
+            gamma_min=25, bkg_syst_fraction=0.075, spectrum=PowerLawSpectralModel()
+        )
 
     sens = SensitivityEstimator(gamma_min=25, bkg_syst_fraction=0.075)
     table = sens.run(dataset_on_off)
 
-    warning_message = (
-        "Table column name energy will be " "deprecated by e_ref since v1.2"
-    )
-    assert "WARNING" in [_.levelname for _ in caplog.records]
-    assert warning_message in [_.message for _ in caplog.records]
-
     assert len(table) == 4
     assert table.colnames == [
-        "energy",
         "e_ref",
         "e_min",
         "e_max",
@@ -96,12 +95,8 @@ def test_integral_estimation(spectrum_dataset, caplog):
     sens = SensitivityEstimator(gamma_min=25, bkg_syst_fraction=0.075)
     table = sens.run(dataset_on_off)
     flux_points = FluxPoints.from_table(
-        table, sed_type="e2dnde", reference_model=sens.spectrum
+        table, sed_type="e2dnde", reference_model=sens.spectral_model
     )
-    assert "WARNING" in [_.levelname for _ in caplog.records]
-    assert "Table column name energy will be deprecated by e_ref since v1.2" in [
-        _.message for _ in caplog.records
-    ]
 
     assert_allclose(table["excess"].data.squeeze(), 270540, rtol=1e-3)
     assert_allclose(flux_points.flux.data.squeeze(), 7.52e-9, rtol=1e-3)
