@@ -8,6 +8,7 @@ import matplotlib.pyplot as plt
 from matplotlib.colors import LogNorm
 from gammapy.maps import MapAxes, MapAxis
 from gammapy.maps.axes import UNIT_STRING_FORMAT
+from gammapy.utils.compat import COPY_IF_NEEDED
 from gammapy.visualization.utils import add_colorbar
 from .core import IRF
 from .io import gadf_is_pointlike
@@ -22,7 +23,8 @@ class BackgroundIRF(IRF):
 
     Parameters
     ----------
-    axes : list of `MapAxis` or `MapAxes` object
+    axes : list of `~gammapy.maps.MapAxis` or `~gammapy.maps.MapAxes`
+        Axes.
     data : `~np.ndarray`
         Data array.
     unit : str or `~astropy.units.Unit`
@@ -73,7 +75,7 @@ class BackgroundIRF(IRF):
         data = table[bkg_name].quantity[0].T
 
         if data.unit == "" or isinstance(data.unit, u.UnrecognizedUnit):
-            data = u.Quantity(data.value, "s-1 MeV-1 sr-1", copy=False)
+            data = u.Quantity(data.value, "s-1 MeV-1 sr-1", copy=COPY_IF_NEEDED)
             log.warning(
                 "Invalid unit found in background table! Assuming (s-1 MeV-1 sr-1)"
             )
@@ -106,8 +108,11 @@ class Background3D(BackgroundIRF):
 
     Parameters
     ----------
-    axes : list of `MapAxis` or `MapAxes` object
-        Required data axes: ["energy", "fov_lon", "fov_lat"] in the given order.
+    axes : list of `~gammapy.maps.MapAxis` or `~gammapy.maps.MapAxes`
+        Required axes (in the given order) are:
+            * energy (reconstructed energy axis)
+            * fov_lon (field of view longitude)
+            * fov_lon (field of view latitude)
     data : `~np.ndarray`
         Data array.
     unit : str or `~astropy.units.Unit`
@@ -258,8 +263,10 @@ class Background2D(BackgroundIRF):
 
     Parameters
     ----------
-    axes : list of `MapAxis` or `MapAxes` object
-        Required data axes: ["energy", "offset"] in the given order.
+    axes : list of `~gammapy.maps.MapAxis` or `~gammapy.maps.MapAxes`
+        Required axes (in the given order) are:
+            * energy (reconstructed energy axis)
+            * offset (field of view offset axis)
     data : `~np.ndarray`
         Data array.
     unit : str or `~astropy.units.Unit`
