@@ -10,6 +10,7 @@ from astropy.io import fits
 from astropy.table import Table
 from astropy.utils import lazyproperty
 from gammapy.maps import Map, MapAxes, MapAxis, RegionGeom
+from gammapy.utils.compat import COPY_IF_NEEDED
 from gammapy.utils.integrate import trapz_loglog
 from gammapy.utils.interpolation import (
     ScaledRegularGridInterpolator,
@@ -32,6 +33,8 @@ class FoVAlignment(str, Enum):
 
     ALTAZ = "ALTAZ"
     RADEC = "RADEC"
+    # used for backward compatibility of old HESS data
+    REVERSE_LON_RADEC = "REVERSE_LON_RADEC"
 
 
 class IRF(metaclass=abc.ABCMeta):
@@ -39,7 +42,7 @@ class IRF(metaclass=abc.ABCMeta):
 
     Parameters
     ----------
-    axes : list of `MapAxis` or `MapAxes`
+    axes : list of `~gammapy.maps.MapAxis` or `~gammapy.maps.MapAxes`
         Axes.
     data : `~numpy.ndarray` or `~astropy.units.Quantity`, optional
         Data. Default is 0.
@@ -205,7 +208,7 @@ class IRF(metaclass=abc.ABCMeta):
     @property
     def quantity(self):
         """Quantity as a `~astropy.units.Quantity` object."""
-        return u.Quantity(self.data, unit=self.unit, copy=False)
+        return u.Quantity(self.data, unit=self.unit, copy=COPY_IF_NEEDED)
 
     @quantity.setter
     def quantity(self, val):
@@ -216,7 +219,7 @@ class IRF(metaclass=abc.ABCMeta):
         value : `~astropy.units.Quantity`
            Quantity.
         """
-        val = u.Quantity(val, copy=False)
+        val = u.Quantity(val, copy=COPY_IF_NEEDED)
         self.data = val.value
         self._unit = val.unit
 
@@ -288,7 +291,7 @@ class IRF(metaclass=abc.ABCMeta):
         for key, value in kwargs.items():
             coord = kwargs.get(key, value)
             if coord is not None:
-                coords_default[key] = u.Quantity(coord, copy=False)
+                coords_default[key] = u.Quantity(coord, copy=COPY_IF_NEEDED)
 
         data = self._interpolate(coords_default.values(), method=method)
 
@@ -345,7 +348,6 @@ class IRF(metaclass=abc.ABCMeta):
         axis = self.axes[axis_name]
         axis_idx = self.axes.index(axis_name)
 
-        # TODO: the broadcasting should be done by axis.center, axis.bin_width etc.
         shape = [1] * len(self.axes)
         shape[axis_idx] = -1
 
@@ -649,7 +651,8 @@ class IRFMap:
     def __init__(self, irf_map, exposure_map):
         self._irf_map = irf_map
         self.exposure_map = exposure_map
-        irf_map.geom.axes.assert_names(self.required_axes)
+        # TODO: only allow for limited set of additional axes?
+        irf_map.geom.axes.assert_names(self.required_axes, allow_extra=True)
 
     @property
     @abc.abstractmethod
@@ -661,6 +664,10 @@ class IRFMap:
     def required_axes(self):
         pass
 
+    @lazyproperty
+    def has_single_spatial_bin(self):
+        return self._irf_map.geom.to_image().data_shape == (1, 1)
+
     # TODO: add mask safe to IRFMap as a regular attribute and don't derive it from the data
     @property
     def mask_safe_image(self):
@@ -794,7 +801,9 @@ class IRFMap:
 
             geom_exposure = geom_psf.squash("rad")
             exposure_map = Map.from_geom(
-                geom=geom_exposure, data=table["Exposure"].data, unit="cm2 s"
+                geom=geom_exposure,
+                data=table["Exposure"].data.reshape(geom_exposure.data_shape),
+                unit="cm2 s",
             )
             return cls(psf_map=psf_map, exposure_map=exposure_map)
         else:
@@ -938,7 +947,7 @@ class IRFMap:
         """Copy IRF map."""
         return deepcopy(self)
 
-    def cutout(self, position, width, mode="trim"):
+    def cutout(self, position, width, mode="trim", min_npix=3):
         """Cutout IRF map.
 
         Parameters
@@ -951,15 +960,22 @@ class IRFMap:
         mode : {'trim', 'partial', 'strict'}, optional
             Mode option for Cutout2D, for details see `~astropy.nddata.utils.Cutout2D`.
             Default is "trim".
+        min_npix : bool, optional
+            Force width to a minimmum number of pixels.
+            Default is 3. The default is 3 pixels so interpolation is done correctly
+            if the binning of the IRF is larger than the width of the analysis region.
 
         Returns
         -------
         cutout : `IRFMap`
             Cutout IRF map.
         """
-        irf_map = self._irf_map.cutout(position, width, mode)
+
+        irf_map = self._irf_map.cutout(position, width, mode, min_npix=min_npix)
         if self.exposure_map:
-            exposure_map = self.exposure_map.cutout(position, width, mode)
+            exposure_map = self.exposure_map.cutout(
+                position, width, mode, min_npix=min_npix
+            )
         else:
             exposure_map = None
         return self.__class__(irf_map, exposure_map=exposure_map)
