@@ -1,18 +1,24 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import logging
 import numpy as np
 import scipy.special
 from astropy import units as u
 from astropy.coordinates import Angle, SkyCoord
+from astropy.units import Quantity
 from astropy.visualization import quantity_support
 import matplotlib.pyplot as plt
 from matplotlib.colors import PowerNorm
 from gammapy.maps import MapAxes, MapAxis, RegionGeom
+from gammapy.utils.deprecation import deprecated_renamed_argument
 from gammapy.visualization.utils import add_colorbar
 from ..core import IRF
 
 __all__ = ["EnergyDispersion2D"]
 
 
+log = logging.getLogger(__name__)
+
+
 class EnergyDispersion2D(IRF):
     """Offset-dependent energy dispersion matrix.
 
@@ -20,12 +26,11 @@ class EnergyDispersion2D(IRF):
 
     Parameters
     ----------
-    energy_axis_true : `MapAxis`
-        True energy axis.
-    migra_axis : `MapAxis`
-        Energy migration axis.
-    offset_axis : `MapAxis`
-        Field of view offset axis.
+    axes : list of `~gammapy.maps.MapAxis` or `~gammapy.maps.MapAxes`
+        Required axes (in the given order) are:
+            * energy_true (true energy axis)
+            * migra (energy migration axis)
+            * offset (field of view offset axis)
     data : `~numpy.ndarray`
         Energy dispersion probability density.
 
@@ -33,7 +38,7 @@ class EnergyDispersion2D(IRF):
     --------
     Read energy dispersion IRF from disk:
 
-    >>> from gammapy.maps import MapAxis
+    >>> from gammapy.maps import MapAxis, MapAxes
     >>> from gammapy.irf import EnergyDispersion2D
     >>> filename = '$GAMMAPY_DATA/hess-dl3-dr1/data/hess_dl3_dr1_obs_id_020136.fits.gz'
     >>> edisp2d = EnergyDispersion2D.read(filename, hdu="EDISP")
@@ -41,8 +46,17 @@ class EnergyDispersion2D(IRF):
     Create energy dispersion matrix (`~gammapy.irf.EnergyDispersion`)
     for a given field of view offset and energy binning:
 
-    >>> energy = MapAxis.from_bounds(0.1, 20, nbin=60, unit="TeV", interp="log").edges
-    >>> edisp = edisp2d.to_edisp_kernel(offset='1.2 deg', energy=energy, energy_true=energy)
+    >>> energy_axis = MapAxis.from_bounds(0.1, 20, nbin=60, unit="TeV", interp="log", name='energy')
+    >>> edisp = edisp2d.to_edisp_kernel(offset='1.2 deg', energy_axis=energy_axis,
+    ...                                 energy_axis_true=energy_axis.copy(name='energy_true'))
+
+    Create energy dispersion IRF from axes:
+
+    >>> energy_axis_true = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=10, name="energy_true")
+    >>> offset_axis = MapAxis.from_bounds(0, 1, nbin=3, unit="deg", name="offset", node_type="edges")
+    >>> migra_axis = MapAxis.from_bounds(0, 3, nbin=3, name="migra", node_type="edges")
+    >>> axes = MapAxes([energy_axis_true, migra_axis, offset_axis])
+    >>> edisp2d_axes = EnergyDispersion2D(axes=axes)
 
     See Also
     --------
@@ -117,7 +131,13 @@ class EnergyDispersion2D(IRF):
             data=data.value,
         )
 
-    def to_edisp_kernel(self, offset, energy_true=None, energy=None):
+    @deprecated_renamed_argument(
+        ["energy_true", "energy"],
+        ["energy_axis_true", "energy_axis"],
+        ["v1.3", "v1.3"],
+        arg_in_kwargs=True,
+    )
+    def to_edisp_kernel(self, offset, energy_axis_true=None, energy_axis=None):
         """Detector response R(Delta E_reco, Delta E_true).
 
         Probability to reconstruct an energy in a given true energy band
@@ -127,9 +147,9 @@ class EnergyDispersion2D(IRF):
         ----------
         offset : `~astropy.coordinates.Angle`
             Offset.
-        energy_true : `~astropy.units.Quantity`, optional
+        energy_axis_true : `~gammapy.maps.MapAxis`, optional
             True energy axis. Default is None.
-        energy : `~astropy.units.Quantity`, optional
+        energy_axis : `~gammapy.maps.MapAxis`, optional
             Reconstructed energy axis. Default is None.
 
         Returns
@@ -141,19 +161,18 @@ class EnergyDispersion2D(IRF):
 
         offset = Angle(offset)
 
-        # TODO: expect directly MapAxis here?
-        if energy is None:
+        if isinstance(energy_axis, Quantity):
+            energy_axis = MapAxis.from_energy_edges(energy_axis)
+        if energy_axis is None:
             energy_axis = self.axes["energy_true"].copy(name="energy")
-        else:
-            energy_axis = MapAxis.from_energy_edges(energy)
 
-        if energy_true is None:
-            energy_axis_true = self.axes["energy_true"]
-        else:
+        if isinstance(energy_axis_true, Quantity):
             energy_axis_true = MapAxis.from_energy_edges(
-                energy_true,
+                energy_axis_true,
                 name="energy_true",
             )
+        if energy_axis_true is None:
+            energy_axis_true = self.axes["energy_true"]
 
         pointing = SkyCoord("0d", "0d")
 
