@@ -5,6 +5,7 @@ import astropy.units as u
 import matplotlib.pyplot as plt
 from gammapy.maps import Map
 from gammapy.modeling.models import PowerLawSpectralModel
+from gammapy.utils.deprecation import deprecated_renamed_argument
 
 __all__ = ["PSFKernel"]
 
@@ -23,7 +24,7 @@ class PSFKernel:
 
     Examples
     --------
-    ::
+    .. testcode::
 
         from gammapy.maps import Map, WcsGeom, MapAxis
         from gammapy.irf import PSFMap
@@ -31,7 +32,7 @@ class PSFKernel:
 
         # Define energy axis
         energy_axis_true = MapAxis.from_energy_bounds(
-            "0.1 TeV", "10 TeV", nbin=4, name="energy_true
+            "0.1 TeV", "10 TeV", nbin=3, name="energy_true"
         )
 
         # Create WcsGeom and map
@@ -50,7 +51,7 @@ class PSFKernel:
         # Do the convolution
         some_map_convolved = some_map.convolve(kernel)
 
-        some_map_convolved.plot_grid();
+        some_map_convolved.plot_grid() # doctest: +SKIP
     """
 
     def __init__(self, psf_kernel_map, normalize=True):
@@ -161,12 +162,13 @@ class PSFKernel:
         """Write the Map object which contains the PSF kernel to file."""
         self.psf_kernel_map.write(*args, **kwargs)
 
-    def to_image(self, spectrum=None, exposure=None, keepdims=True):
+    @deprecated_renamed_argument("spectrum", "spectral_model", "v1.3")
+    def to_image(self, spectral_model=None, exposure=None, keepdims=True):
         """Transform 3D PSFKernel into a 2D PSFKernel.
 
         Parameters
         ----------
-        spectrum : `~gammapy.modeling.models.SpectralModel`, optional
+        spectral_model : `~gammapy.modeling.models.SpectralModel`, optional
             Spectral model to compute the weights.
             Default is power-law with spectral index of 2.
         exposure : `~astropy.units.Quantity` or `~numpy.ndarray`, optional
@@ -184,8 +186,8 @@ class PSFKernel:
         """
         map = self.psf_kernel_map
 
-        if spectrum is None:
-            spectrum = PowerLawSpectralModel(index=2.0)
+        if spectral_model is None:
+            spectral_model = PowerLawSpectralModel(index=2.0)
 
         if exposure is None:
             exposure = np.ones(map.geom.axes[0].center.shape)
@@ -200,7 +202,7 @@ class PSFKernel:
             if "energy" in name:
                 energy_name = name
         energy_edges = map.geom.axes[energy_name].edges
-        weights = spectrum.integral(
+        weights = spectral_model.integral(
             energy_min=energy_edges[:-1], energy_max=energy_edges[1:], intervals=True
         )
         weights *= exposure
