@@ -162,7 +162,7 @@ class ParametricPSF(PSF):
             column = table[spec[name]]
             values = column.data[0].transpose()
 
-            # TODO: this fixes some files where sigma is written as zero
+            # This fixes some files where sigma is written as zero
             if "sigma" in name:
                 values[values == 0] = 1.0
 
@@ -300,8 +300,11 @@ class EnergyDependentMultiGaussPSF(ParametricPSF):
 
     Parameters
     ----------
-    axes : list of `MapAxis`
-        Required axes are ["energy_true", "offset"].
+    axes : list of `~gammapy.maps.MapAxis` or `~gammapy.maps.MapAxes`
+        Required axes (in the given order) are:
+            * energy_true (true energy axis)
+            * migra_axis (energy migration axis)
+            * offset_axis (field of view offset axis)
     data : `~numpy.recarray`
         Data array.
     meta : dict
