@@ -436,7 +436,8 @@ class ReflectedRegionsBackgroundMaker(Maker):
         If not given, a `ReflectedRegionsFinder` will be created and
         any of the ``**kwargs`` will be forwarded to the `ReflectedRegionsFinder`.
     exclusion_mask : `~gammapy.maps.WcsNDMap`, optional
-        Exclusion mask.
+        Exclusion mask. The map must contain at max one non-spatial dimension, and this
+        dimension must be one bin.
     """
 
     tag = "ReflectedRegionsBackgroundMaker"
@@ -451,6 +452,13 @@ class ReflectedRegionsBackgroundMaker(Maker):
         if exclusion_mask and not exclusion_mask.is_mask:
             raise ValueError("Exclusion mask must contain boolean values")
 
+        if exclusion_mask and not exclusion_mask.geom.is_flat:
+            raise ValueError("Exclusion mask must only contain spatial dimension")
+
+        if exclusion_mask:
+            exclusion_mask = exclusion_mask.sum_over_axes(keepdims=False)
+            exclusion_mask.data = exclusion_mask.data.astype("bool")
+
         self.exclusion_mask = exclusion_mask
 
         if region_finder is None:
@@ -494,7 +502,7 @@ class ReflectedRegionsBackgroundMaker(Maker):
         ----------
         dataset : `~gammapy.datasets.SpectrumDataset`
             Spectrum dataset.
-        observation : `~gammapy.observation.Observation`
+        observation : `~gammapy.data.Observation`
             Observation container.
 
         Returns
@@ -561,14 +569,14 @@ class ReflectedRegionsBackgroundMaker(Maker):
 
         Parameters
         ----------
-        dataset : `SpectrumDataset`
+        dataset : `~gammapy.datasets.SpectrumDataset`
             Spectrum dataset.
-        observation : `DatastoreObservation`
+        observation : `~gammapy.data.Observation`
             Data store observation.
 
         Returns
         -------
-        dataset_on_off : `SpectrumDatasetOnOff`
+        dataset_on_off : `~gammapy.datasets.SpectrumDatasetOnOff`
             On-Off dataset.
         """
         counts_off, acceptance_off = self.make_counts_off(dataset, observation)
