@@ -131,11 +131,9 @@ def test_fov_bkg_maker_fit(obs_dataset, exclusion_mask):
 
     model = dataset.models[f"{dataset.name}-bkg"].spectral_model
     assert_allclose(model.norm.value, 0.901523, rtol=1e-4)
+    assert_allclose(model.norm.error, 0.60880, rtol=1e-4)
     assert_allclose(model.tilt.value, 0.071069, rtol=1e-4)
-
-    # TODO: reactivate with a more stable error estimate
-    # assert_allclose(model.norm.error, 0.355637, rtol=1e-2)
-    # assert_allclose(model.tilt.error, 0.342201, rtol=1e-2)
+    assert_allclose(model.tilt.error, 0.586600, rtol=1e-4)
 
     assert_allclose(fov_bkg_maker.default_spectral_model.tilt.value, 0.0)
     assert_allclose(fov_bkg_maker.default_spectral_model.norm.value, 1.0)
