@@ -17,9 +17,11 @@ log = logging.getLogger(__name__)
 class SafeMaskMaker(Maker):
     """Make safe data range mask for a given observation.
 
+    For more information see :ref:`safe-data-range`.
+
     .. warning::
 
-         Currently some methods computing a safe energy range ("aeff-default",
+         Currently, some methods computing a safe energy range ("aeff-default",
          "aeff-max" and "edisp-bias") determine a true energy range and apply
          it to reconstructed energy, effectively neglecting the energy dispersion.
 
@@ -62,7 +64,7 @@ class SafeMaskMaker(Maker):
 
     def __init__(
         self,
-        methods=("aeff-default",),
+        methods=["aeff-default"],
         aeff_percent=10,
         bias_percent=10,
         position=None,
@@ -280,7 +282,7 @@ class SafeMaskMaker(Maker):
         The energy threshold is defined as the lower edge of the energy
         bin with the highest predicted background rate. This is to ensure analysis in
         a region where a  Powerlaw approximation to the background spectrum is valid.
-        The is motivated by its use in the HESS DL3
+        The is motivated by its use in the H.E.S.S. DL3
         validation paper: https://arxiv.org/pdf/1910.08088.pdf
 
         Parameters
