@@ -11,6 +11,7 @@ from astropy import units as u
 from astropy.io import fits
 import matplotlib.pyplot as plt
 import gammapy.utils.parallel as parallel
+from gammapy.utils.compat import COPY_IF_NEEDED
 from gammapy.utils.random import InverseCDFSampler, get_random_state
 from gammapy.utils.scripts import make_path
 from gammapy.utils.types import JsonQuantityDecoder
@@ -107,7 +108,12 @@ class Map(abc.ABC):
             raise TypeError("Map data must be a Numpy array. Set unit separately")
 
         if not value.shape == self.geom.data_shape:
-            value = value.reshape(self.geom.data_shape)
+            try:
+                value = np.broadcast_to(value, self.geom.data_shape, subok=True)
+            except ValueError as exc:
+                raise ValueError(
+                    f"Input shape {value.shape} is not compatible with shape from geometry {self.geom.data_shape}"
+                ) from exc
 
         self._data = value
 
@@ -128,7 +134,7 @@ class Map(abc.ABC):
     @property
     def quantity(self):
         """Map data as a `~astropy.units.Quantity` object."""
-        return u.Quantity(self.data, self.unit, copy=False)
+        return u.Quantity(self.data, self.unit, copy=COPY_IF_NEEDED)
 
     @quantity.setter
     def quantity(self, val):
@@ -139,7 +145,7 @@ class Map(abc.ABC):
         val : `~astropy.units.Quantity`
            Quantity.
         """
-        val = u.Quantity(val, copy=False)
+        val = u.Quantity(val, copy=COPY_IF_NEEDED)
 
         self.data = val.value
         self._unit = val.unit
@@ -252,7 +258,7 @@ class Map(abc.ABC):
             Map object.
         """
         with fits.open(
-            str(make_path(filename)), memmap=False, checksum=checksum
+            make_path(filename), memmap=False, checksum=checksum
         ) as hdulist:
             return Map.from_hdulist(
                 hdulist, hdu, hdu_bands, map_type, format=format, colname=colname
@@ -554,7 +560,7 @@ class Map(abc.ABC):
             'constant' pads with a constant value. 'interp' pads with
             an extrapolated value. Default is 'constant'.
         cval : float, optional
-            Padding value when `mode`='consant'. Default is 0.
+            Padding value when ``mode='consant'``. Default is 0.
 
         Returns
         -------
@@ -769,6 +775,13 @@ class Map(abc.ABC):
         -------
         map_out : `Map`
             Sliced map object.
+
+        Examples
+        --------
+        >>> from gammapy.maps import Map
+        >>> m = Map.read("$GAMMAPY_DATA/fermi_3fhl/gll_iem_v06_cutout.fits")
+        >>> slices = {"energy": slice(0, 5)}
+        >>> sliced = m.slice_by_idx(slices)
         """
         geom = self.geom.slice_by_idx(slices)
         slices = tuple([slices.get(ax.name, slice(None)) for ax in self.geom.axes])
@@ -1023,6 +1036,7 @@ class Map(abc.ABC):
             the map is a differential quantity (e.g. intensity). Default is False.
         fill_value : float, optional
             The value to use for points outside the interpolation domain.
+            If None, values outside the domain are extrapolated.
             Default is 0.
         **kwargs : dict, optional
             Keyword arguments passed to `Map.interp_by_coord`.
@@ -1043,12 +1057,14 @@ class Map(abc.ABC):
                 )
             map_copy.data /= map_copy.geom.solid_angle().to_value("deg2")
 
-        if map_copy.is_mask:
+        if map_copy.is_mask and fill_value is not None:
             # TODO: check this NaN handling is needed
             data = map_copy.get_by_coord(coords)
             data = np.nan_to_num(data, nan=fill_value).astype(bool)
         else:
             data = map_copy.interp_by_coord(coords, fill_value=fill_value, **kwargs)
+            if map_copy.is_mask:
+                data = data.astype(bool)
 
         if preserve_counts:
             data *= geom.solid_angle().to_value("deg2")
@@ -1655,7 +1671,7 @@ class Map(abc.ABC):
         cumsum = self.cumsum(axis_name=axis_name)
         cumsum = cumsum.pad(pad_width=1, axis_name=axis_name, mode="edge")
         return u.Quantity(
-            cumsum.interp_by_coord(coords, **kwargs), cumsum.unit, copy=False
+            cumsum.interp_by_coord(coords, **kwargs), cumsum.unit, copy=COPY_IF_NEEDED
         )
 
     def normalize(self, axis_name=None):
@@ -1718,9 +1734,10 @@ class Map(abc.ABC):
 
             data.append(m.quantity.to_value(maps[0].unit))
 
-        return cls.from_geom(
-            data=np.stack(data), geom=geom.to_cube(axes=[axis]), unit=maps[0].unit
-        )
+        new_geom = geom.to_cube(axes=[axis])
+        data = np.concatenate(data).reshape(new_geom.data_shape)
+
+        return cls.from_geom(data=data, geom=new_geom, unit=maps[0].unit)
 
     def split_by_axis(self, axis_name):
         """Split a Map along an axis into multiple maps.
@@ -1865,7 +1882,7 @@ class Map(abc.ABC):
             else:
                 raise ValueError("Map Arithmetic: Inconsistent geometries.")
         else:
-            q = u.Quantity(other, copy=False)
+            q = u.Quantity(other, copy=COPY_IF_NEEDED)
 
         out = self.copy() if copy else self
         out.quantity = operator(out.quantity, q)
@@ -1892,25 +1909,25 @@ class Map(abc.ABC):
         return self._arithmetics(np.add, other, copy=True)
 
     def __iadd__(self, other):
-        return self._arithmetics(np.add, other, copy=False)
+        return self._arithmetics(np.add, other, copy=COPY_IF_NEEDED)
 
     def __sub__(self, other):
         return self._arithmetics(np.subtract, other, copy=True)
 
     def __isub__(self, other):
-        return self._arithmetics(np.subtract, other, copy=False)
+        return self._arithmetics(np.subtract, other, copy=COPY_IF_NEEDED)
 
     def __mul__(self, other):
         return self._arithmetics(np.multiply, other, copy=True)
 
     def __imul__(self, other):
-        return self._arithmetics(np.multiply, other, copy=False)
+        return self._arithmetics(np.multiply, other, copy=COPY_IF_NEEDED)
 
     def __truediv__(self, other):
         return self._arithmetics(np.true_divide, other, copy=True)
 
     def __itruediv__(self, other):
-        return self._arithmetics(np.true_divide, other, copy=False)
+        return self._arithmetics(np.true_divide, other, copy=COPY_IF_NEEDED)
 
     def __le__(self, other):
         return self._arithmetics(np.less_equal, other, copy=True)
@@ -1943,13 +1960,13 @@ class Map(abc.ABC):
         return self._boolean_arithmetics(np.logical_xor, other, copy=True)
 
     def __iand__(self, other):
-        return self._boolean_arithmetics(np.logical_and, other, copy=False)
+        return self._boolean_arithmetics(np.logical_and, other, copy=COPY_IF_NEEDED)
 
     def __ior__(self, other):
-        return self._boolean_arithmetics(np.logical_or, other, copy=False)
+        return self._boolean_arithmetics(np.logical_or, other, copy=COPY_IF_NEEDED)
 
     def __ixor__(self, other):
-        return self._boolean_arithmetics(np.logical_xor, other, copy=False)
+        return self._boolean_arithmetics(np.logical_xor, other, copy=COPY_IF_NEEDED)
 
     def __array__(self):
         return self.data
