@@ -47,7 +47,7 @@ def pix_tuple_to_idx(pix):
             idx += [p]
         else:
             with np.errstate(invalid="ignore"):
-                p_idx = np.rint(p).astype(int)
+                p_idx = np.floor(p + 0.5).astype(int)
             p_idx[~np.isfinite(p)] = INVALID_INDEX.int
             idx += [p_idx]
 
@@ -353,6 +353,15 @@ class Geom(abc.ABC):
         -------
         geom : `~Geom`
             Sliced geometry.
+
+        Examples
+        --------
+        >>> from gammapy.maps import MapAxis, WcsGeom
+        >>> import astropy.units as u
+        >>> energy_axis = MapAxis.from_energy_bounds(1*u.TeV, 3*u.TeV, 6)
+        >>> geom = WcsGeom.create(skydir=(83.63, 22.01), axes=[energy_axis], width=5, binsz=0.02)
+        >>> slices = {"energy": slice(0, 2)}
+        >>> sliced_geom = geom.slice_by_idx(slices)
         """
         axes = self.axes.slice_by_idx(slices)
         return self._init_copy(axes=axes)
@@ -625,8 +634,9 @@ class Geom(abc.ABC):
 
         Returns
         -------
-        mask : `~numpy.ndarray`
-            Energy mask.
+        mask : `~gammapy.maps.Map`
+            Map containing the energy mask. The geometry of the map
+            is the same as the geometry of the instance which called this method.
         """
         from . import Map
 
