@@ -6,6 +6,7 @@ from astropy.coordinates import SkyCoord
 from astropy.io import fits
 from regions import PointSkyRegion
 import matplotlib.pyplot as plt
+from gammapy.utils.compat import COPY_IF_NEEDED
 from gammapy.utils.units import unit_from_fits_image_hdu
 from ..coord import MapCoord
 from ..geom import pix_tuple_to_idx
@@ -211,9 +212,10 @@ class HpxNDMap(HpxMap):
                         cnames.append(c)
             nbin = len(cnames)
             if nbin == 1:
-                map_out.data = hdu.data.field(cnames[0])
+                map_out.data = hdu.data.field(cnames[0]).reshape(geom.data_shape)
             else:
                 for idx, cname in enumerate(cnames):
+                    # TODO: check whether reshaping is needed here. Is this tested?
                     idx = np.unravel_index(idx, shape)
                     map_out.data[idx + (slice(None),)] = hdu.data.field(cname)
 
@@ -398,7 +400,7 @@ class HpxNDMap(HpxMap):
         if self.geom.is_allsky:
             idx = geom._ipix
         else:
-            idx = self.geom.to_image().global_to_local((geom._ipix,))
+            idx = self.geom.to_image().global_to_local((geom._ipix,))[0]
 
         data = self.data[..., idx]
         return self.__class__(geom=geom, data=data, unit=self.unit, meta=self.meta)
@@ -755,7 +757,9 @@ class HpxNDMap(HpxMap):
                 idx = np.clip(idx, 0, len(ax.center) - 2)
 
                 w = ax.center[idx + 1] - ax.center[idx]
-                c = u.Quantity(coords[ax.name], ax.center.unit, copy=False).value
+                c = u.Quantity(
+                    coords[ax.name], ax.center.unit, copy=COPY_IF_NEEDED
+                ).value
 
                 if i & (1 << j):
                     wt *= (c - ax.center[idx].value) / w.value
