@@ -437,6 +437,24 @@ def test_interp_to_geom():
     assert isinstance(interp_wcs_map, WcsNDMap)
     assert interp_wcs_map.geom == wcs_geom_target
 
+    # WcsNDMap is_mask
+    geom_wcs = WcsGeom.create(
+        npix=(5, 3), proj="CAR", binsz=0.1, axes=[energy], skydir=(0, 0)
+    )
+
+    wcs_map = Map.from_geom(geom_wcs, unit="", data=True)
+    wcs_geom_target = WcsGeom.create(
+        skydir=(30, 30),
+        width=(10, 10),
+        binsz=0.1 * u.deg,
+        axes=[energy_target],
+        frame="galactic",
+    )
+    interp_wcs_map = wcs_map.interp_to_geom(
+        wcs_geom_target, method="linear", fill_value=None
+    )
+    assert np.all(interp_wcs_map.data)
+
     # HpxNDMap
     geom_hpx = HpxGeom.create(binsz=60, axes=[energy], skydir=(0, 0))
     hpx_map = Map.from_geom(geom_hpx, unit="")
@@ -945,3 +963,30 @@ def test_map_dot_product():
     assert dot_map.data.shape == (4, 2, 3, 1, 1)
 
     assert_allclose(dot_map.data[0, :, 0, 0, 0], [1, 0])
+
+
+def test_data_shape_broadcast():
+    axis1 = MapAxis.from_edges((0, 1, 3), name="axis1")
+
+    map1 = WcsNDMap.create(npix=(5, 6), axes=[axis1])
+
+    with pytest.raises(ValueError):
+        map1.data = np.zeros((1, 2, 6, 5))
+
+    with pytest.raises(ValueError):
+        map1.data = np.zeros((2, 6, 5, 1))
+
+    map2: RegionNDMap = RegionNDMap.create(region=None, axes=[axis1])
+
+    map2.data = np.ones((2,))
+    assert_allclose(map2.data, 1)
+    assert map2.data.shape == (2, 1, 1)
+
+    map2.data = np.zeros((2, 1, 1))
+    assert_allclose(map2.data, 0)
+
+    with pytest.raises(ValueError):
+        map2.data = np.ones((2, 1))
+
+    with pytest.raises(ValueError):
+        map2.data = np.ones((1, 1, 2))
