@@ -17,6 +17,7 @@ from astropy.wcs.utils import (
 )
 from regions import RectangleSkyRegion
 from gammapy.utils.array import round_up_to_even, round_up_to_odd
+from gammapy.utils.compat import COPY_IF_NEEDED
 from ..axes import MapAxes
 from ..coord import MapCoord, skycoord_to_lonlat
 from ..geom import Geom, get_shape, pix_tuple_to_idx
@@ -670,8 +671,8 @@ class WcsGeom(Geom):
             coords = self._wcs.wcs_pix2world(pix[0], pix[1], 0)
 
         coords = (
-            u.Quantity(coords[0], unit="deg", copy=False),
-            u.Quantity(coords[1], unit="deg", copy=False),
+            u.Quantity(coords[0], unit="deg", copy=COPY_IF_NEEDED),
+            u.Quantity(coords[1], unit="deg", copy=COPY_IF_NEEDED),
         )
 
         coords += self.axes.pix_to_coord(pix[self._slice_non_spatial_axes])
@@ -847,7 +848,9 @@ class WcsGeom(Geom):
         # TODO: for non-negative cdelt a negative solid angle is returned
         #  find out why and fix properly
 
-        value = np.abs(u.Quantity(area_low_right + area_up_left, "sr", copy=False))
+        value = np.abs(
+            u.Quantity(area_low_right + area_up_left, "sr", copy=COPY_IF_NEEDED)
+        )
         if self.is_regular:
             value = value.reshape(self.data_shape_image)
         return value
@@ -882,7 +885,7 @@ class WcsGeom(Geom):
         coord = self.to_image().get_coord()
         return center.separation(coord.skycoord)
 
-    def cutout(self, position, width, mode="trim", odd_npix=False):
+    def cutout(self, position, width, mode="trim", odd_npix=False, min_npix=1):
         """
         Create a cutout around a given position.
 
@@ -899,6 +902,10 @@ class WcsGeom(Geom):
         odd_npix : bool, optional
             Force width to odd number of pixels.
             Default is False.
+        min_npix : bool, optional
+            Force width to a minimmum number of pixels.
+            Default is 1.
+
 
         Returns
         -------
@@ -908,7 +915,7 @@ class WcsGeom(Geom):
         width = _check_width(width) * u.deg
 
         binsz = self.pixel_scales
-        width_npix = np.clip((width / binsz).to_value(""), 1, None)
+        width_npix = np.clip((width / binsz).to_value(""), min_npix, None)
 
         if odd_npix:
             width_npix = round_up_to_odd(width_npix)
