@@ -726,16 +726,12 @@ class WcsNDMap(WcsMap):
 
         # This is likely not the most efficient way to do this
         data = np.apply_along_axis(
-            lambda a: np.histogram(a, bins=bins_axis.edges, density=density)[0],
+            lambda a: np.histogram(a, bins=bins_axis.edges.value, density=density)[0],
             axis=-1,
-            arr=quantity,
+            arr=quantity.to_value(bins_axis.unit),
         )
 
-        if density:
-            unit = 1.0 / bins_axis.unit
-            data = data.value
-        else:
-            unit = ""
+        unit = 1.0 / bins_axis.unit if density else ""
 
         return RegionNDMap.from_geom(geom=geom_hist, data=data, unit=unit)
 
@@ -979,7 +975,7 @@ class WcsNDMap(WcsMap):
 
         return self._init_copy(data=smoothed_data)
 
-    def cutout(self, position, width, mode="trim", odd_npix=False):
+    def cutout(self, position, width, mode="trim", odd_npix=False, min_npix=1):
         """
         Create a cutout around a given position.
 
@@ -996,6 +992,9 @@ class WcsNDMap(WcsMap):
         odd_npix : bool, optional
             Force width to odd number of pixels.
             Default is False.
+        min_npix : bool, optional
+            Force width to a minimmum number of pixels.
+            Default is 1.
 
         Returns
         -------
@@ -1003,7 +1002,11 @@ class WcsNDMap(WcsMap):
             Cutout map.
         """
         geom_cutout = self.geom.cutout(
-            position=position, width=width, mode=mode, odd_npix=odd_npix
+            position=position,
+            width=width,
+            mode=mode,
+            odd_npix=odd_npix,
+            min_npix=min_npix,
         )
         cutout_info = geom_cutout.cutout_slices(self.geom, mode=mode)
 
