@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Models and fitting."""
 from .covariance import Covariance
-from .fit import Fit
+from .fit import CovarianceResult, Fit, FitResult, OptimizeResult
 from .parameter import Parameter, Parameters, PriorParameter, PriorParameters
 from .scipy import stat_profile_ul_scipy
 from .selection import select_nested_models
@@ -9,6 +9,9 @@ from .selection import select_nested_models
 __all__ = [
     "Covariance",
     "Fit",
+    "FitResult",
+    "OptimizeResult",
+    "CovarianceResult",
     "Parameter",
     "Parameters",
     "select_nested_models",
