@@ -15,7 +15,7 @@ from .iminuit import (
 from .scipy import confidence_scipy, optimize_scipy
 from .sherpa import optimize_sherpa
 
-__all__ = ["Fit"]
+__all__ = ["Fit", "FitResult", "OptimizeResult", "CovarianceResult"]
 
 log = logging.getLogger(__name__)
 
@@ -165,6 +165,8 @@ class Fit:
             Fit result.
         """
 
+        datasets, parameters = self._parse_datasets(datasets=datasets)
+
         optimize_result = self.optimize(datasets=datasets)
 
         if self.backend not in registry.register["covariance"]:
@@ -179,6 +181,8 @@ class Fit:
             optimize_result.models.parameters, covariance_result.matrix
         )
 
+        datasets._covariance = Covariance(parameters, covariance_result.matrix)
+
         return FitResult(
             optimize_result=optimize_result,
             covariance_result=covariance_result,
@@ -300,7 +304,7 @@ class Fit:
             method=method,
             success=info["success"],
             message=info["message"],
-            matrix=optimize_result.models.covariance.data,
+            matrix=matrix.data,
         )
 
     def confidence(self, datasets, parameter, sigma=1, reoptimize=True):
@@ -311,7 +315,7 @@ class Fit:
 
         For the scipy backend ``kwargs`` are forwarded to `~scipy.optimize.brentq`. If the
         confidence estimation fails, the bracketing interval can be adapted by modifying the
-        the upper bound of the interval (``b``) value.
+        upper bound of the interval (``b``) value.
 
         Parameters
         ----------
@@ -377,6 +381,25 @@ class Fit:
         results : dict
             Dictionary with keys "parameter_name_scan", "stat_scan" and "fit_results". The latter contains an
             empty list, if `reoptimize` is set to False.
+
+        Examples
+        --------
+        >>> from gammapy.datasets import Datasets, SpectrumDatasetOnOff
+        >>> from gammapy.modeling.models import SkyModel, LogParabolaSpectralModel
+        >>> from gammapy.modeling import Fit
+        >>> datasets = Datasets()
+        >>> for obs_id in [23523, 23526]:
+        ...     dataset = SpectrumDatasetOnOff.read(
+        ...         f"$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs{obs_id}.fits"
+        ...     )
+        ...     datasets.append(dataset)
+        >>> datasets = datasets.stack_reduce(name="HESS")
+        >>> model = SkyModel(spectral_model=LogParabolaSpectralModel(), name="crab")
+        >>> datasets.models = model
+        >>> fit = Fit()
+        >>> result = fit.run(datasets)
+        >>> parameter = datasets.models.parameters['amplitude']
+        >>> stat_profile = fit.stat_profile(datasets=datasets, parameter=parameter)
         """
         datasets, parameters = self._parse_datasets(datasets=datasets)
 
@@ -434,6 +457,33 @@ class Fit:
         results : dict
             Dictionary with keys "x_values", "y_values", "stat" and "fit_results".
             The latter contains an empty list, if `reoptimize` is set to False.
+
+        Examples
+        --------
+        >>> from gammapy.datasets import Datasets, SpectrumDatasetOnOff
+        >>> from gammapy.modeling.models import SkyModel, LogParabolaSpectralModel
+        >>> from gammapy.modeling import Fit
+        >>> import numpy as np
+        >>> datasets = Datasets()
+        >>> for obs_id in [23523, 23526]:
+        ...     dataset = SpectrumDatasetOnOff.read(
+        ...         f"$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs{obs_id}.fits"
+        ...     )
+        ...     datasets.append(dataset)
+        >>> datasets = datasets.stack_reduce(name="HESS")
+        >>> model = SkyModel(spectral_model=LogParabolaSpectralModel(), name="crab")
+        >>> datasets.models = model
+        >>> par_alpha = datasets.models.parameters["alpha"]
+        >>> par_beta = datasets.models.parameters["beta"]
+        >>> par_alpha.scan_values = np.linspace(1.55, 2.7, 20)
+        >>> par_beta.scan_values = np.linspace(-0.05, 0.55, 20)
+        >>> fit = Fit()
+        >>> stat_surface = fit.stat_surface(
+        ...     datasets=datasets,
+        ...     x=par_alpha,
+        ...     y=par_beta,
+        ...     reoptimize=False,
+        ... )
         """
         datasets, parameters = self._parse_datasets(datasets=datasets)
 
@@ -505,7 +555,30 @@ class Fit:
         result : dict
             Dictionary containing the parameter values defining the contour, with the
             boolean flag "success" and the information objects from ``mncontour``.
+
+        Examples
+        --------
+        >>> from gammapy.datasets import Datasets, SpectrumDatasetOnOff
+        >>> from gammapy.modeling.models import SkyModel, LogParabolaSpectralModel
+        >>> from gammapy.modeling import Fit
+        >>> datasets = Datasets()
+        >>> for obs_id in [23523, 23526]:
+        ...     dataset = SpectrumDatasetOnOff.read(
+        ...         f"$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs{obs_id}.fits"
+        ...     )
+        ...     datasets.append(dataset)
+        >>> datasets = datasets.stack_reduce(name="HESS")
+        >>> model = SkyModel(spectral_model=LogParabolaSpectralModel(), name="crab")
+        >>> datasets.models = model
+        >>> fit = Fit(backend='minuit')
+        >>> optimize = fit.optimize(datasets)
+        >>> stat_contour = fit.stat_contour(
+        ...     datasets=datasets,
+        ...     x=model.spectral_model.alpha,
+        ...     y=model.spectral_model.amplitude,
+        ... )
         """
+
         datasets, parameters = self._parse_datasets(datasets=datasets)
 
         x = parameters[x]
@@ -579,9 +652,28 @@ class FitStepResult:
         except AttributeError:
             return f"<pre>{html.escape(str(self))}</pre>"
 
+    def to_dict(self):
+        """Convert to dictionary."""
+        return {
+            self.__class__.__name__: {
+                "backend": self.backend,
+                "method": self.method,
+                "success": self.success,
+                "message": self.message,
+            }
+        }
+
 
 class CovarianceResult(FitStepResult):
-    """Covariance result object."""
+    """Covariance result object.
+
+    Parameters
+    ----------
+    matrix : `~numpy.ndarray`, optional
+        The covariance matrix. Default is None.
+    kwargs : dict
+        Extra ``kwargs`` are passed to the backend.
+    """
 
     def __init__(self, matrix=None, **kwargs):
         self._matrix = matrix
@@ -594,7 +686,23 @@ class CovarianceResult(FitStepResult):
 
 
 class OptimizeResult(FitStepResult):
-    """Optimize result object."""
+    """Optimize result object.
+
+    Parameters
+    ----------
+    models : `~gammapy.modeling.models.DatasetModels`
+        Best fit models.
+    nfev : int
+        Number of function evaluations.
+    total_stat : float
+        Value of the fit statistic at minimum.
+    trace : `~astropy.table.Table`
+        Parameter trace from the optimisation.
+    minuit : `~iminuit.minuit.Minuit`, optional
+        Minuit object. Default is None.
+    kwargs : dict
+        Extra ``kwargs`` are passed to the backend.
+    """
 
     def __init__(self, models, nfev, total_stat, trace, minuit=None, **kwargs):
         self._models = models
@@ -640,15 +748,24 @@ class OptimizeResult(FitStepResult):
         string += f"\ttotal stat : {self.total_stat:.2f}\n\n"
         return string
 
+    def to_dict(self):
+        """Convert to dictionary."""
+        output = super().to_dict()
+        output[self.__class__.__name__]["nfev"] = self.nfev
+        output[self.__class__.__name__]["total_stat"] = float(self._total_stat)
+        return output
+
 
 class FitResult:
     """Fit result class.
 
+    The fit result class provides the results from the optimisation and covariance of the fit.
+
     Parameters
     ----------
-    optimize_result : `OptimizeResult`
+    optimize_result : `~OptimizeResult`
         Result of the optimization step.
-    covariance_result : `CovarianceResult`
+    covariance_result : `~CovarianceResult`
         Result of the covariance step.
     """
 
@@ -721,6 +838,48 @@ class FitResult:
         """Optimize result."""
         return self._covariance_result
 
+    def write(
+        self,
+        path,
+        overwrite=False,
+        full_output=True,
+        overwrite_templates=False,
+        write_covariance=True,
+        checksum=False,
+    ):
+        """Write to file.
+
+        Parameters
+        ----------
+        path : `pathlib.Path` or str
+            Path to write files.
+        overwrite : bool, optional
+            Overwrite existing file. Default is False.
+        full_output : bool, optional
+            Store full parameter output. Default is True.
+        overwrite_templates : bool, optional
+            Overwrite templates FITS files. Default is False.
+        checksum : bool, optional
+            When True adds a CHECKSUM entry to the file.
+            Default is False.
+        """
+        from gammapy.modeling.models.core import _write_models
+
+        output = {}
+        if self.optimize_result is not None:
+            output.update(self.optimize_result.to_dict())
+        if self.covariance_result is not None:
+            output.update(self.covariance_result.to_dict())
+        _write_models(
+            self.models,
+            path,
+            overwrite,
+            full_output,
+            overwrite_templates,
+            write_covariance,
+            extra_dict=output,
+        )
+
     def __str__(self):
         string = ""
         if self.optimize_result:
