@@ -1,4 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import html
 
 __all__ = ["Likelihood"]
 
@@ -18,9 +19,9 @@ class Likelihood:
     Parameters
     ----------
     parameters : `~gammapy.modeling.Parameters`
-        Parameters with starting values
+        Parameters with starting values.
     function : callable
-        Likelihood function
+        Likelihood function.
     """
 
     def __init__(self, function, parameters, store_trace):
@@ -45,3 +46,9 @@ class Likelihood:
             self.store_trace_iteration(total_stat)
 
         return total_stat
+
+    def _repr_html_(self):
+        try:
+            return self.to_html()
+        except AttributeError:
+            return f"<pre>{html.escape(str(self))}</pre>"
