@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Built-in models in Gammapy."""
+
 from gammapy.utils.registry import Registry
 from .core import DatasetModels, Model, ModelBase, Models
 from .cube import (
@@ -108,6 +109,9 @@ __all__ = [
     "PowerLawNormSpectralModel",
     "PowerLawSpectralModel",
     "PowerLawTemporalModel",
+    "Prior",
+    "GaussianPrior",
+    "UniformPrior",
     "scale_plot_flux",
     "ScaleSpectralModel",
     "Shell2SpatialModel",
