@@ -3,19 +3,16 @@ import collections.abc
 import copy
 import html
 import logging
-import warnings
 from os.path import split
 import numpy as np
 import astropy.units as u
 from astropy.coordinates import SkyCoord
 from astropy.table import Table
 import matplotlib.pyplot as plt
-import yaml
 from gammapy.maps import Map, RegionGeom
 from gammapy.modeling import Covariance, Parameter, Parameters
-from gammapy.utils.check import add_checksum, verify_checksum
-from gammapy.utils.metadata import CreatorMetaData
-from gammapy.utils.scripts import make_name, make_path
+from gammapy.modeling.covariance import CovarianceMixin
+from gammapy.utils.scripts import from_yaml, make_name, make_path, to_yaml, write_yaml
 
 __all__ = ["Model", "Models", "DatasetModels", "ModelBase"]
 
@@ -80,6 +77,54 @@ def _build_parameters_from_dict(data, default_parameters):
     return Parameters.from_dict(par_data)
 
 
+def _check_name_unique(model, names):
+    """Check if a model is not duplicated"""
+    if model.name in names:
+        raise (
+            ValueError(
+                f"Model names must be unique. Models named '{model.name}' are duplicated."
+            )
+        )
+    return
+
+
+def _write_models(
+    models,
+    path,
+    overwrite=False,
+    full_output=False,
+    overwrite_templates=False,
+    write_covariance=True,
+    checksum=False,
+    extra_dict=None,
+):
+    """Write models to YAML file with additionnal informations using an `extra_dict`"""
+
+    base_path, _ = split(path)
+    path = make_path(path)
+    base_path = make_path(base_path)
+
+    if path.exists() and not overwrite:
+        raise IOError(f"File exists already: {path}")
+
+    if (
+        write_covariance
+        and models.covariance is not None
+        and len(models.parameters) != 0
+    ):
+        filecovar = path.stem + "_covariance.dat"
+        kwargs = dict(format="ascii.fixed_width", delimiter="|", overwrite=overwrite)
+        models.write_covariance(base_path / filecovar, **kwargs)
+        models._covar_file = filecovar
+
+    yaml_str = ""
+    if extra_dict is not None:
+        yaml_str += to_yaml(extra_dict)
+    yaml_str += models.to_yaml(full_output, overwrite_templates)
+
+    write_yaml(yaml_str, path, overwrite=overwrite, checksum=checksum)
+
+
 class ModelBase:
     """Model base class."""
 
@@ -174,6 +219,10 @@ class ModelBase:
             [getattr(self, name) for name in self.default_parameters.names]
         )
 
+    @property
+    def parameters_unique_names(self):
+        return self.parameters.unique_parameters.names
+
     def copy(self, **kwargs):
         """Deep copy."""
         return copy.deepcopy(self)
@@ -192,7 +241,6 @@ class ModelBase:
                     "error",
                     "interp",
                     "scale_method",
-                    "is_norm",
                 ]:
                     default = init[item]
 
@@ -326,7 +374,7 @@ class Model:
         return cls.from_dict(data)
 
 
-class DatasetModels(collections.abc.Sequence):
+class DatasetModels(collections.abc.Sequence, CovarianceMixin):
     """Immutable models container.
 
     Parameters
@@ -342,6 +390,8 @@ class DatasetModels(collections.abc.Sequence):
             models = []
 
         if isinstance(models, (Models, DatasetModels)):
+            if covariance_data is None and models.covariance is not None:
+                covariance_data = models.covariance.data
             models = models._models
         elif isinstance(models, ModelBase):
             models = [models]
@@ -351,8 +401,7 @@ class DatasetModels(collections.abc.Sequence):
         unique_names = []
 
         for model in models:
-            if model.name in unique_names:
-                raise (ValueError("Model names must be unique"))
+            _check_name_unique(model, names=unique_names)
             unique_names.append(model.name)
 
         self._models = models
@@ -364,31 +413,6 @@ class DatasetModels(collections.abc.Sequence):
         if covariance_data is not None:
             self.covariance = covariance_data
 
-    def _check_covariance(self):
-        if not self.parameters == self._covariance.parameters:
-            self._covariance = Covariance.from_stack(
-                [model.covariance for model in self._models]
-            )
-
-    @property
-    def covariance(self):
-        """Covariance as a `~gammapy.modeling.Covariance` object."""
-        self._check_covariance()
-
-        for model in self._models:
-            self._covariance.set_subcovariance(model.covariance)
-
-        return self._covariance
-
-    @covariance.setter
-    def covariance(self, covariance):
-        self._check_covariance()
-        self._covariance.data = covariance
-
-        for model in self._models:
-            subcovar = self._covariance.get_subcovariance(model.covariance.parameters)
-            model.covariance = subcovar
-
     @property
     def parameters(self):
         """Parameters as a `~gammapy.modeling.Parameters` object."""
@@ -398,12 +422,11 @@ class DatasetModels(collections.abc.Sequence):
     def parameters_unique_names(self):
         """List of unique parameter names. Return formatted as model_name.par_type.par_name."""
         names = []
-        for model in self:
-            for par in model.parameters:
-                components = [model.name, par.type, par.name]
+        for model in self._models:
+            for par_name in model.parameters_unique_names:
+                components = [model.name, par_name]
                 name = ".".join(components)
                 names.append(name)
-
         return names
 
     @property
@@ -419,7 +442,7 @@ class DatasetModels(collections.abc.Sequence):
         ----------
         filename : str
             input filename
-        checksum : bool
+        checksum : bool, optional
             Whether to perform checksum verification. Default is False.
         """
         yaml_str = make_path(filename).read_text()
@@ -428,16 +451,20 @@ class DatasetModels(collections.abc.Sequence):
 
     @classmethod
     def from_yaml(cls, yaml_str, path="", checksum=False):
-        """Create from YAML string."""
-        data = yaml.safe_load(yaml_str)
-        checksum_str = data.pop("checksum", None)
-        if checksum:
-            yaml_str = yaml.dump(
-                data, sort_keys=False, indent=4, width=80, default_flow_style=False
-            )
-            if not verify_checksum(yaml_str, checksum_str):
-                warnings.warn("Checksum verification failed.", UserWarning)
+        """Create from YAML string.
 
+        Parameters
+        ----------
+        yaml_str : str
+            yaml str
+        path : str
+            base path of model files
+        checksum : bool, optional
+            Whether to perform checksum verification. Default is False.
+
+
+        """
+        data = from_yaml(yaml_str, checksum=checksum)
         # TODO : for now metadata are not kept. Add proper metadata creation.
         data.pop("metadata", None)
         return cls.from_dict(data, path=path)
@@ -502,42 +529,32 @@ class DatasetModels(collections.abc.Sequence):
             Overwrite templates FITS files. Default is False.
         write_covariance : bool, optional
             Whether to save the covariance. Default is True.
-        checksum : bool
+        checksum : bool, optional
             When True adds a CHECKSUM entry to the file.
             Default is False.
         """
-        base_path, _ = split(path)
-        path = make_path(path)
-        base_path = make_path(base_path)
-
-        if path.exists() and not overwrite:
-            raise IOError(f"File exists already: {path}")
-
-        if (
-            write_covariance
-            and self.covariance is not None
-            and len(self.parameters) != 0
-        ):
-            filecovar = path.stem + "_covariance.dat"
-            kwargs = dict(
-                format="ascii.fixed_width", delimiter="|", overwrite=overwrite
-            )
-            self.write_covariance(base_path / filecovar, **kwargs)
-            self._covar_file = filecovar
-
-        yaml_str = self.to_yaml(full_output, overwrite_templates)
-        if checksum:
-            yaml_str = add_checksum(yaml_str)
-        path.write_text(yaml_str)
+        _write_models(
+            self,
+            path,
+            overwrite,
+            full_output,
+            overwrite_templates,
+            write_covariance,
+            checksum,
+        )
 
     def to_yaml(self, full_output=False, overwrite_templates=False):
-        """Convert to YAML string."""
+        """Convert to YAML string.
+
+        Parameters
+        ----------
+         full_output : bool, optional
+            Store full parameter output. Default is False.
+        overwrite_templates : bool, optional
+            Overwrite templates FITS files. Default is False.
+        """
         data = self.to_dict(full_output, overwrite_templates)
-        text = yaml.dump(
-            data, sort_keys=False, indent=4, width=80, default_flow_style=False
-        )
-        creation = CreatorMetaData()
-        return text + creation.to_yaml()
+        return to_yaml(data)
 
     def update_link_label(self):
         """Update linked parameters labels used for serialisation and print."""
@@ -655,8 +672,7 @@ class DatasetModels(collections.abc.Sequence):
         if isinstance(other, (Models, list)):
             return Models([*self, *other])
         elif isinstance(other, ModelBase):
-            if other.name in self.names:
-                raise (ValueError("Model names must be unique"))
+            _check_name_unique(other, self.names)
             return Models([*self, other])
         else:
             raise TypeError(f"Invalid type: {other!r}")
@@ -1199,9 +1215,7 @@ class Models(DatasetModels, collections.abc.MutableSequence):
             raise TypeError(f"Invalid type: {model!r}")
 
     def insert(self, idx, model):
-        if model.name in self.names:
-            raise (ValueError("Model names must be unique"))
-
+        _check_name_unique(model, self.names)
         self._models.insert(idx, model)
 
     def set_prior(self, parameters, priors):
