@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Spatial models."""
+
 import logging
 import os
 import numpy as np
@@ -21,6 +22,7 @@ from regions import (
 import matplotlib.pyplot as plt
 from gammapy.maps import HpxNDMap, Map, MapCoord, WcsGeom, WcsNDMap
 from gammapy.modeling import Parameter, Parameters
+from gammapy.utils.compat import COPY_IF_NEEDED
 from gammapy.utils.gauss import Gauss2DPDF
 from gammapy.utils.interpolation import interpolation_scale
 from gammapy.utils.regions import region_circle_to_ellipse, region_to_frame
@@ -651,7 +653,7 @@ class GaussianSpatialModel(SpatialModel):
             norm = (1 / (2 * np.pi * sigma * minor_axis)).to_value("sr-1")
 
         exponent = -0.5 * ((1 - np.cos(sep)) / a)
-        return u.Quantity(norm * np.exp(exponent).value, "sr-1", copy=False)
+        return u.Quantity(norm * np.exp(exponent).value, "sr-1", copy=COPY_IF_NEEDED)
 
     def to_region(self, x_sigma=1.5, **kwargs):
         r"""Model outline at a given number of :math:`\sigma`.
@@ -937,7 +939,7 @@ class DiskSpatialModel(SpatialModel):
         in_ellipse = DiskSpatialModel._evaluate_smooth_edge(
             sep - sigma_eff, sigma_eff * edge_width
         )
-        return u.Quantity(norm * in_ellipse, "sr-1", copy=False)
+        return u.Quantity(norm * in_ellipse, "sr-1", copy=COPY_IF_NEEDED)
 
     def to_region(self, **kwargs):
         """Model outline as a `~regions.EllipseSkyRegion`."""
@@ -1259,8 +1261,8 @@ class TemplateSpatialModel(SpatialModel):
     """Spatial sky map template model.
 
     For more information see :ref:`template-spatial-model`.
-    By default the position of the model is fixed at the center of the map.
-    The position can be fittted by unfreezing the `lon_0` and `lat_0 `parameters.
+    By default, the position of the model is fixed at the center of the map.
+    The position can be fitted by unfreezing the `lon_0` and `lat_0` parameters.
     In that case, the coordinate of every pixel is shifted in lon and lat
     in the frame of the map. NOTE: planar distances are calculated, so
     the results are correct only when the fitted position is close to the
@@ -1277,7 +1279,7 @@ class TemplateSpatialModel(SpatialModel):
     interp_kwargs : dict
         Interpolation keyword arguments passed to `gammapy.maps.Map.interp_by_coord`.
         Default arguments are {'method': 'linear', 'fill_value': 0, "values_scale": "log"}.
-    Filename : str
+    filename : str
         Name of the map file.
     copy_data : bool
         Create a deepcopy of the map data or directly use the original. Default is True.
@@ -1304,6 +1306,8 @@ class TemplateSpatialModel(SpatialModel):
             log.warning("Map has negative values. Check and fix this!")
         if (map.data == 0.0).all():
             log.warning("Map values are all zeros. Check and fix this!")
+        if np.isnan(map.data).any():
+            log.warning("Map has NaN values. Check and fix this!")
         if not map.geom.is_image and (map.data.sum(axis=(1, 2)) == 0).any():
             log.warning(
                 "Map values are all zeros in at least one energy bin. Check and fix this!"
@@ -1323,7 +1327,10 @@ class TemplateSpatialModel(SpatialModel):
                 data_sum = map.data.sum(axis=(1, 2)).reshape((-1, 1, 1))
 
             data = np.divide(
-                map.data, data_sum, out=np.zeros_like(map.data), where=data_sum != 0
+                map.data.astype(float),
+                data_sum,
+                out=np.zeros_like(map.data, dtype=float),
+                where=data_sum != 0,
             )
             data /= map.geom.solid_angle().to_value("sr")
             map = map.copy(data=data, unit="sr-1")
@@ -1462,7 +1469,7 @@ class TemplateSpatialModel(SpatialModel):
 
         val = self.map.interp_by_coord(coord, **self._interp_kwargs)
         val = np.clip(val, 0, a_max=None)
-        return u.Quantity(val, self.map.unit, copy=False)
+        return u.Quantity(val, self.map.unit, copy=COPY_IF_NEEDED)
 
     @property
     def position_lonlat(self):
@@ -1493,7 +1500,7 @@ class TemplateSpatialModel(SpatialModel):
         data["spatial"]["unit"] = str(self.map.unit)
         return data
 
-    def write(self, overwrite=False):
+    def write(self, overwrite=False, filename=None):
         """
         Write the map.
 
@@ -1502,10 +1509,16 @@ class TemplateSpatialModel(SpatialModel):
         overwrite: bool, optional
             Overwrite existing file.
             Default is False, which will raise a warning if the template file exists already.
+        filename: str, optional
+            Filename of the template model. By default, the template model
+            will be saved with the `TemplateSpatialModel.filename` attribute,
+            if `filename` is provided this attribute will be updated.
         """
+        if filename is not None:
+            self.filename = filename
         if self.filename is None:
             raise IOError("Missing filename")
-        elif os.path.isfile(make_path(self.filename)) and not overwrite:
+        if os.path.isfile(make_path(self.filename)) and not overwrite:
             log.warning("Template file already exits, and overwrite is False")
         else:
             self.map.write(self.filename, overwrite=overwrite)
@@ -1614,7 +1627,7 @@ class TemplateNDSpatialModel(SpatialModel):
         val = self.map.interp_by_coord(coord, **self._interp_kwargs)
         val = np.clip(val, 0, a_max=None)
 
-        return u.Quantity(val, self.map.unit, copy=False)
+        return u.Quantity(val, self.map.unit, copy=COPY_IF_NEEDED)
 
     def write(self, overwrite=False):
         """
@@ -1674,9 +1687,9 @@ class PiecewiseNormSpatialModel(SpatialModel):
 
     def __init__(self, coords, norms=None, interp="lin", **kwargs):
         self._coords = coords.copy()
-        self._coords["lon"] = Angle(coords.lon).wrap_at(0 * u.deg)
-        self._wrap_angle = (coords.lon.max() - coords.lon.min()) / 2
-        self._coords["lon"] = Angle(coords.lon).wrap_at(self._wrap_angle)
+        lon = Angle(coords.lon).wrap_at(0 * u.deg)
+        self._wrap_angle = (lon.max() - lon.min()) / 2
+        self._coords["lon"] = Angle(lon).wrap_at(self._wrap_angle)
         self._interp = interp
 
         if norms is None:
@@ -1722,6 +1735,7 @@ class PiecewiseNormSpatialModel(SpatialModel):
         coords = [value.value for value in self.coords._data.values()]
         # TODO: apply axes scaling in this loop
         coords = list(zip(*coords))
+        lon = Angle(lon).wrap_at(0 * u.deg)
         lon = Angle(lon).wrap_at(self._wrap_angle)
         # by default rely on CloughTocher2DInterpolator
         # (Piecewise cubic, C1 smooth, curvature-minimizing interpolant)
