@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Spectral models for Gammapy."""
+
 import logging
 import operator
 import os
@@ -11,12 +12,14 @@ import scipy.special
 import astropy.units as u
 from astropy import constants as const
 from astropy.table import Table
+from astropy.units import Quantity
 from astropy.utils.decorators import classproperty
 from astropy.visualization import quantity_support
 import matplotlib.pyplot as plt
 from gammapy.maps import MapAxis, RegionNDMap
 from gammapy.maps.axes import UNIT_STRING_FORMAT
 from gammapy.modeling import Parameter, Parameters
+from gammapy.utils.compat import COPY_IF_NEEDED
 from gammapy.utils.deprecation import GammapyDeprecationWarning
 from gammapy.utils.integrate import trapz_loglog
 from gammapy.utils.interpolation import (
@@ -25,6 +28,7 @@ from gammapy.utils.interpolation import (
 )
 from gammapy.utils.roots import find_roots
 from gammapy.utils.scripts import make_path
+from ..covariance import CovarianceMixin
 from .core import ModelBase
 
 log = logging.getLogger(__name__)
@@ -426,8 +430,9 @@ class SpectralModel(ModelBase):
 
         Parameters
         ----------
-        energy_bounds : `~astropy.units.Quantity`
-            Plot energy bounds passed to MapAxis.from_energy_bounds.
+        energy_bounds : `~astropy.units.Quantity`, list of `~astropy.units.Quantity` or `~gammapy.maps.MapAxis`
+            Energy bounds between which the model is to be plotted. Or an
+            axis defining the energy bounds between which the model is to be plotted.
         ax : `~matplotlib.axes.Axes`, optional
             Matplotlib axes. Default is None.
         sed_type : {"dnde", "flux", "eflux", "e2dnde"}
@@ -443,20 +448,28 @@ class SpectralModel(ModelBase):
         -------
         ax : `~matplotlib.axes.Axes`, optional
             Matplotlib axes.
+
+        Notes
+        -----
+        If ``energy_bounds`` is supplied as a list, tuple, or Quantity, an ``energy_axis`` is created internally with
+        ``n_points`` bins between the given bounds.
         """
         from gammapy.estimators.map.core import DEFAULT_UNIT
 
-        ax = plt.gca() if ax is None else ax
-
         if self.is_norm_spectral_model:
             sed_type = "norm"
 
-        energy_min, energy_max = energy_bounds
-        energy = MapAxis.from_energy_bounds(
-            energy_min,
-            energy_max,
-            n_points,
-        )
+        if isinstance(energy_bounds, (tuple, list, Quantity)):
+            energy_min, energy_max = energy_bounds
+            energy = MapAxis.from_energy_bounds(
+                energy_min,
+                energy_max,
+                n_points,
+            )
+        elif isinstance(energy_bounds, MapAxis):
+            energy = energy_bounds
+
+        ax = plt.gca() if ax is None else ax
 
         if ax.yaxis.units is None:
             ax.yaxis.set_units(DEFAULT_UNIT[sed_type] * energy.unit**energy_power)
@@ -498,8 +511,9 @@ class SpectralModel(ModelBase):
 
         Parameters
         ----------
-        energy_bounds : `~astropy.units.Quantity`
-            Plot energy bounds passed to `~gammapy.maps.MapAxis.from_energy_bounds`.
+        energy_bounds : `~astropy.units.Quantity`, list of `~astropy.units.Quantity` or `~gammapy.maps.MapAxis`
+            Energy bounds between which the model is to be plotted. Or an
+            axis defining the energy bounds between which the model is to be plotted.
         ax : `~matplotlib.axes.Axes`, optional
             Matplotlib axes. Default is None.
         sed_type : {"dnde", "flux", "eflux", "e2dnde"}
@@ -515,20 +529,28 @@ class SpectralModel(ModelBase):
         -------
         ax : `~matplotlib.axes.Axes`, optional
             Matplotlib axes.
+
+        Notes
+        -----
+        If ``energy_bounds`` is supplied as a list, tuple, or Quantity, an ``energy_axis`` is created internally with
+        ``n_points`` bins between the given bounds.
         """
         from gammapy.estimators.map.core import DEFAULT_UNIT
 
-        ax = plt.gca() if ax is None else ax
-
         if self.is_norm_spectral_model:
             sed_type = "norm"
 
-        energy_min, energy_max = energy_bounds
-        energy = MapAxis.from_energy_bounds(
-            energy_min,
-            energy_max,
-            n_points,
-        )
+        if isinstance(energy_bounds, (tuple, list, Quantity)):
+            energy_min, energy_max = energy_bounds
+            energy = MapAxis.from_energy_bounds(
+                energy_min,
+                energy_max,
+                n_points,
+            )
+        elif isinstance(energy_bounds, MapAxis):
+            energy = energy_bounds
+
+        ax = plt.gca() if ax is None else ax
 
         kwargs.setdefault("facecolor", "black")
         kwargs.setdefault("alpha", 0.2)
@@ -627,7 +649,7 @@ class SpectralModel(ModelBase):
 
         def f(x):
             # scale by 1e12 to achieve better precision
-            energy = u.Quantity(x, eunit, copy=False)
+            energy = u.Quantity(x, eunit, copy=COPY_IF_NEEDED)
             y = self(energy).to_value(value.unit)
             return 1e12 * (y - value.value)
 
@@ -674,7 +696,6 @@ class ConstantSpectralModel(SpectralModel):
 
     tag = ["ConstantSpectralModel", "const"]
     const = Parameter("const", "1e-12 cm-2 s-1 TeV-1")
-    const._is_norm = True
 
     @staticmethod
     def evaluate(energy, const):
@@ -682,7 +703,7 @@ class ConstantSpectralModel(SpectralModel):
         return np.ones(np.atleast_1d(energy).shape) * const
 
 
-class CompoundSpectralModel(SpectralModel):
+class CompoundSpectralModel(CovarianceMixin, SpectralModel):
     """Arithmetic combination of two spectral models.
 
     For more information see :ref:`compound-spectral-model`.
@@ -696,10 +717,24 @@ class CompoundSpectralModel(SpectralModel):
         self.operator = operator
         super().__init__()
 
+    @property
+    def _models(self):
+        return [self.model1, self.model2]
+
     @property
     def parameters(self):
         return self.model1.parameters + self.model2.parameters
 
+    @property
+    def parameters_unique_names(self):
+        names = []
+        for idx, model in enumerate(self._models):
+            for par_name in model.parameters_unique_names:
+                components = [f"model{idx+1}", par_name]
+                name = ".".join(components)
+                names.append(name)
+        return names
+
     def __str__(self):
         return (
             f"{self.__class__.__name__}\n"
@@ -775,7 +810,6 @@ class PowerLawSpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     reference = Parameter("reference", "1 TeV", frozen=True)
 
     @staticmethod
@@ -900,7 +934,6 @@ class PowerLawNormSpectralModel(SpectralModel):
 
     tag = ["PowerLawNormSpectralModel", "pl-norm"]
     norm = Parameter("norm", 1, unit="", interp="log")
-    norm._is_norm = True
     tilt = Parameter("tilt", 0, frozen=True)
     reference = Parameter("reference", "1 TeV", frozen=True)
 
@@ -1013,7 +1046,6 @@ class PowerLaw2SpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     index = Parameter("index", 2)
     emin = Parameter("emin", "0.1 TeV", frozen=True)
     emax = Parameter("emax", "100 TeV", frozen=True)
@@ -1105,7 +1137,6 @@ class BrokenPowerLawSpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     ebreak = Parameter("ebreak", "1 TeV")
 
     @staticmethod
@@ -1153,7 +1184,6 @@ class SmoothBrokenPowerLawSpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     ebreak = Parameter("ebreak", "1 TeV")
     reference = Parameter("reference", "1 TeV", frozen=True)
     beta = Parameter("beta", 1, frozen=True)
@@ -1291,7 +1321,6 @@ class ExpCutoffPowerLawSpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     reference = Parameter("reference", "1 TeV", frozen=True)
     lambda_ = Parameter("lambda_", "0.1 TeV-1")
     alpha = Parameter("alpha", "1.0", frozen=True)
@@ -1331,7 +1360,7 @@ class ExpCutoffPowerLawNormSpectralModel(SpectralModel):
     ----------
     index : `~astropy.units.Quantity`
         :math:`\Gamma`.
-        Default is 1.5.
+        Default is 0.
     norm : `~astropy.units.Quantity`
         :math:`\phi_0`.
         Default is 1.
@@ -1352,9 +1381,8 @@ class ExpCutoffPowerLawNormSpectralModel(SpectralModel):
 
     tag = ["ExpCutoffPowerLawNormSpectralModel", "ecpl-norm"]
 
-    index = Parameter("index", 1.5)
+    index = Parameter("index", 0.0)
     norm = Parameter("norm", 1, unit="", interp="log")
-    norm._is_norm = True
     reference = Parameter("reference", "1 TeV", frozen=True)
     lambda_ = Parameter("lambda_", "0.1 TeV-1")
     alpha = Parameter("alpha", "1.0", frozen=True)
@@ -1362,10 +1390,9 @@ class ExpCutoffPowerLawNormSpectralModel(SpectralModel):
     def __init__(
         self, index=None, norm=None, reference=None, lambda_=None, alpha=None, **kwargs
     ):
-
         if index is None:
             warnings.warn(
-                "The default index value changed from 1.5 to 0 since v1.2",
+                "The default index value changed from 1.5 to 0 since v1.3",
                 GammapyDeprecationWarning,
             )
 
@@ -1420,7 +1447,6 @@ class ExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     reference = Parameter("reference", "1 TeV", frozen=True)
     ecut = Parameter("ecut", "10 TeV")
 
@@ -1469,7 +1495,6 @@ class SuperExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     reference = Parameter("reference", "1 TeV", frozen=True)
     ecut = Parameter("ecut", "10 TeV")
     index_1 = Parameter("index_1", 1.5)
@@ -1512,7 +1537,6 @@ class SuperExpCutoffPowerLaw4FGLSpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     reference = Parameter("reference", "1 TeV", frozen=True)
     expfactor = Parameter("expfactor", "1e-2")
     index_1 = Parameter("index_1", 1.5)
@@ -1521,11 +1545,14 @@ class SuperExpCutoffPowerLaw4FGLSpectralModel(SpectralModel):
     @staticmethod
     def evaluate(energy, amplitude, reference, expfactor, index_1, index_2):
         """Evaluate the model (static function)."""
+        if isinstance(index_1, u.Quantity):
+            index_1 = index_1.to_value(u.one)
+        if isinstance(index_2, u.Quantity):
+            index_2 = index_2.to_value(u.one)
+
         pwl = amplitude * (energy / reference) ** (-index_1)
         cutoff = np.exp(
-            expfactor
-            / reference.unit**index_2
-            * (reference**index_2 - energy**index_2)
+            expfactor / reference.unit**index_2 * (reference**index_2 - energy**index_2)
         )
         return pwl * cutoff
 
@@ -1557,7 +1584,6 @@ class SuperExpCutoffPowerLaw4FGLDR3SpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     reference = Parameter("reference", "1 TeV", frozen=True)
     expfactor = Parameter("expfactor", "1e-2")
     index_1 = Parameter("index_1", 1.5)
@@ -1609,7 +1635,6 @@ class LogParabolaSpectralModel(SpectralModel):
         scale_method="scale10",
         interp="log",
     )
-    amplitude._is_norm = True
     reference = Parameter("reference", "10 TeV", frozen=True)
     alpha = Parameter("alpha", 2)
     beta = Parameter("beta", 1)
@@ -1664,25 +1689,11 @@ class LogParabolaNormSpectralModel(SpectralModel):
     tag = ["LogParabolaNormSpectralModel", "lp-norm"]
 
     norm = Parameter("norm", 1, unit="", interp="log")
-    norm._is_norm = True
     reference = Parameter("reference", "10 TeV", frozen=True)
     alpha = Parameter("alpha", 0)
     beta = Parameter("beta", 0)
 
     def __init__(self, norm=None, reference=None, alpha=None, beta=None, **kwargs):
-
-        if alpha is None:
-            warnings.warn(
-                "The default alpha value changed from 2 to 0 since v1.2",
-                GammapyDeprecationWarning,
-            )
-
-        if beta is None:
-            warnings.warn(
-                "The default beta value changed from 1 to 0 since v1.2",
-                GammapyDeprecationWarning,
-            )
-
         if norm is not None:
             kwargs.update({"norm": norm})
         if beta is not None:
@@ -1720,10 +1731,10 @@ class TemplateSpectralModel(SpectralModel):
     values : `~numpy.ndarray`
         Array with the values of the model at energies ``energy``.
     interp_kwargs : dict
-        Interpolation keyword arguments passed to `scipy.interpolate.RegularGridInterpolator`.
-        By default all values outside the interpolation range are set to zero.
-        If you want to apply linear extrapolation you can pass `interp_kwargs={'fill_value':
-        'extrapolate', 'kind': 'linear'}`. If you want to choose the interpolation
+        Interpolation option passed to `~gammapy.utils.interpolation.ScaledRegularGridInterpolator`.
+        By default, all values outside the interpolation range are set to NaN.
+        If you want to apply linear extrapolation you can pass `interp_kwargs={'extrapolate':
+        True, 'method': 'linear'}`. If you want to choose the interpolation
         scaling applied to values, you can use `interp_kwargs={"values_scale": "log"}`.
     meta : dict, optional
         Meta information, meta['filename'] will be used for serialisation.
@@ -1739,7 +1750,7 @@ class TemplateSpectralModel(SpectralModel):
         meta=None,
     ):
         self.energy = energy
-        self.values = u.Quantity(values, copy=False)
+        self.values = u.Quantity(values, copy=COPY_IF_NEEDED)
         self.meta = {} if meta is None else meta
         interp_kwargs = interp_kwargs or {}
         interp_kwargs.setdefault("values_scale", "log")
@@ -1799,7 +1810,9 @@ class TemplateSpectralModel(SpectralModel):
         # Get spectrum values (no interpolation, take closest value for param)
         table_spectra = Table.read(filename, hdu="SPECTRA")
         idx = np.abs(table_spectra["PARAMVAL"] - param).argmin()
-        values = u.Quantity(table_spectra[idx][1], "", copy=False)  # no dimension
+        values = u.Quantity(
+            table_spectra[idx][1], "", copy=COPY_IF_NEEDED
+        )  # no dimension
 
         kwargs.setdefault("interp_kwargs", {"values_scale": "lin"})
         return cls(energy=energy, values=values, **kwargs)
@@ -1901,7 +1914,7 @@ class TemplateNDSpectralModel(SpectralModel):
         ]
 
         val = self.map.interp_by_pix(pixels, **self._interp_kwargs)
-        return u.Quantity(val, self.map.unit, copy=False)
+        return u.Quantity(val, self.map.unit, copy=COPY_IF_NEEDED)
 
     def write(self, overwrite=False):
         """
@@ -2001,7 +2014,7 @@ class EBLAbsorptionNormSpectralModel(SpectralModel):
         # set values log centers
         self.param = param
         self.energy = energy
-        self.data = u.Quantity(data, copy=False)
+        self.data = u.Quantity(data, copy=COPY_IF_NEEDED)
 
         interp_kwargs = interp_kwargs or {}
         interp_kwargs.setdefault("points_scale", ("lin", "log"))
@@ -2095,10 +2108,10 @@ class EBLAbsorptionNormSpectralModel(SpectralModel):
         # Get energy values
         table_energy = Table.read(filename, hdu="ENERGIES")
         energy_lo = u.Quantity(
-            table_energy["ENERG_LO"], "keV", copy=False
+            table_energy["ENERG_LO"], "keV", copy=COPY_IF_NEEDED
         )  # unit not stored in file
         energy_hi = u.Quantity(
-            table_energy["ENERG_HI"], "keV", copy=False
+            table_energy["ENERG_HI"], "keV", copy=COPY_IF_NEEDED
         )  # unit not stored in file
         energy = np.sqrt(energy_lo * energy_hi)
 
@@ -2363,7 +2376,6 @@ class GaussianSpectralModel(SpectralModel):
 
     tag = ["GaussianSpectralModel", "gauss"]
     amplitude = Parameter("amplitude", 1e-12 * u.Unit("cm-2 s-1"), interp="log")
-    amplitude._is_norm = True
 
     mean = Parameter("mean", 1 * u.TeV)
     sigma = Parameter("sigma", 2 * u.TeV)
