@@ -2,6 +2,7 @@
 import numpy as np
 from astropy import units as u
 from gammapy.modeling import Parameter
+from gammapy.utils.compat import COPY_IF_NEEDED
 from .spectral import (
     ExpCutoffPowerLawSpectralModel,
     LogParabolaSpectralModel,
@@ -22,7 +23,6 @@ class MeyerCrabSpectralModel(SpectralModel):
     """
 
     norm = Parameter("norm", value=1, frozen=True)
-    norm._is_norm = True
     coefficients = [-0.00449161, 0, 0.0473174, -0.179475, -0.53616, -10.2708]
 
     @staticmethod
@@ -31,7 +31,7 @@ class MeyerCrabSpectralModel(SpectralModel):
         polynomial = np.poly1d(MeyerCrabSpectralModel.coefficients)
         log_energy = np.log10(energy.to_value("TeV"))
         log_flux = polynomial(log_energy)
-        flux = u.Quantity(np.power(10, log_flux), "erg / (cm2 s)", copy=False)
+        flux = u.Quantity(np.power(10, log_flux), "erg / (cm2 s)", copy=COPY_IF_NEEDED)
         return norm * flux / energy**2
 
 
