@@ -1,4 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import sys
 import pytest
 from numpy.testing import assert_allclose
 import astropy.units as u
@@ -11,6 +12,7 @@ from gammapy.modeling.models import (
     Model,
     ModelBase,
     Models,
+    PointSpatialModel,
     PowerLawSpectralModel,
     SkyModel,
 )
@@ -213,7 +215,7 @@ def test_plot_models(caplog):
     models = Models.read("$GAMMAPY_DATA/tests/models/gc_example_models.yaml")
 
     with mpl_plot_check():
-        models.plot_positions()
+        models.plot_regions(linewidth=2)
         models.plot_regions()
 
     assert models.wcs_geom.data_shape == models.wcs_geom.wcs.array_shape
@@ -261,7 +263,15 @@ def test_positions():
 
 
 def test_parameter_name():
-    with pytest.raises(RuntimeError):
+    # From the 3.12 changelog:
+    # Exceptions raised in a class or type’s __set_name__ method are no longer
+    # wrapped by a RuntimeError.
+    if sys.version_info < (3, 12):
+        exc_class = RuntimeError
+    else:
+        exc_class = ValueError
+
+    with pytest.raises(exc_class):
 
         class MyTestModel:
             par = Parameter("wrong-name", value=3)
@@ -309,3 +319,33 @@ def test_to_template():
 
     assert_allclose(values_ref, values_direct, rtol=1e-5)
     assert_allclose(values_ref, values_from3d, rtol=1e-5)
+
+
+def test_add_not_unique_models():
+    spec_model1 = PowerLawSpectralModel()
+    spatial_model1 = PointSpatialModel()
+
+    model1 = SkyModel(
+        spectral_model=spec_model1, spatial_model=spatial_model1, name="source1"
+    )
+
+    model2 = SkyModel(
+        spectral_model=spec_model1, spatial_model=spatial_model1, name="source2"
+    )
+
+    model3 = SkyModel(
+        spectral_model=spec_model1, spatial_model=spatial_model1, name="source3"
+    )
+
+    model4 = SkyModel(
+        spectral_model=spec_model1, spatial_model=spatial_model1, name="source1"
+    )
+
+    models1 = Models([model1, model2])
+    models2 = Models([model3, model4])
+
+    with pytest.raises(
+        ValueError,
+        match="Model names must be unique. Models named 'source1' are duplicated.",
+    ):
+        models1.extend(models2)
