@@ -26,7 +26,7 @@ from gammapy.modeling.models import (
     TemplateNPredModel,
 )
 from gammapy.utils.deprecation import GammapyDeprecationWarning
-from gammapy.utils.scripts import make_path, read_yaml, write_yaml
+from gammapy.utils.scripts import make_path, read_yaml, to_yaml, write_yaml
 from gammapy.utils.testing import requires_data, requires_dependency
 
 
@@ -306,7 +306,7 @@ def test_absorption_io(tmp_path):
     assert_allclose(new_model.param, model.param)
     assert_allclose(new_model.data, model.data)
 
-    write_yaml(model_dict, tmp_path / "tmp.yaml")
+    write_yaml(to_yaml(model_dict), tmp_path / "tmp.yaml")
     read_yaml(tmp_path / "tmp.yaml")
 
 
@@ -317,9 +317,7 @@ def test_naima_model():
     particle_distribution = naima.models.PowerLaw(
         amplitude=2e33 / u.eV, e_0=10 * u.TeV, alpha=2.5
     )
-    radiative_model = naima.radiative.PionDecay(
-        particle_distribution, nh=1 * u.cm**-3
-    )
+    radiative_model = naima.radiative.PionDecay(particle_distribution, nh=1 * u.cm**-3)
     yield Model.create(
         "NaimaSpectralModel", "spectral", radiative_model=radiative_model
     )
@@ -362,8 +360,6 @@ def make_all_models():
     yield Model.create("SuperExpCutoffPowerLaw4FGLDR3SpectralModel", "spectral")
     yield Model.create("SuperExpCutoffPowerLaw4FGLSpectralModel", "spectral")
     yield Model.create("LogParabolaSpectralModel", "spectral")
-    with pytest.warns(GammapyDeprecationWarning):
-        yield Model.create("LogParabolaNormSpectralModel", "spectral")
     yield Model.create(
         "TemplateSpectralModel", "spectral", energy=[1, 2] * u.cm, values=[3, 4] * u.cm
     )  # TODO: add unit validation?
@@ -520,13 +516,13 @@ def test_compound_models_io(tmp_path):
     assert_allclose(sk1.covariance.data, sk.covariance.data, rtol=1e-3)
     assert_allclose(np.sum(sk1.covariance.data), 0.0)
     assert Models([sk]).parameters_unique_names == [
-        "model.spectral.index",
-        "model.spectral.amplitude",
-        "model.spectral.reference",
-        "model.spectral.amplitude",
-        "model.spectral.reference",
-        "model.spectral.alpha",
-        "model.spectral.beta",
+        "model.spectral.model1.index",
+        "model.spectral.model1.amplitude",
+        "model.spectral.model1.reference",
+        "model.spectral.model2.amplitude",
+        "model.spectral.model2.reference",
+        "model.spectral.model2.alpha",
+        "model.spectral.model2.beta",
     ]
 
 
