@@ -32,6 +32,7 @@ from gammapy.modeling.models import (
     TemplateNDSpectralModel,
     TemplateSpectralModel,
 )
+from gammapy.utils.compat import COPY_IF_NEEDED
 from gammapy.utils.scripts import make_path
 from gammapy.utils.testing import (
     assert_quantity_allclose,
@@ -431,6 +432,7 @@ def test_model_plot():
         amplitude=1e-12 * u.Unit("TeV-1 cm-2 s-1"), reference=1 * u.Unit("TeV"), index=2
     )
     pwl.amplitude.error = 0.1e-12 * u.Unit("TeV-1 cm-2 s-1")
+    energy_axis = MapAxis.from_energy_bounds(1 * u.TeV, 10 * u.TeV, 100)
 
     with mpl_plot_check():
         pwl.plot((1 * u.TeV, 10 * u.TeV))
@@ -438,6 +440,24 @@ def test_model_plot():
     with mpl_plot_check():
         pwl.plot_error((1 * u.TeV, 10 * u.TeV))
 
+    with mpl_plot_check():
+        pwl.plot([0.08, 20] * u.TeV)
+
+    with mpl_plot_check():
+        pwl.plot_error([0.08, 20] * u.TeV)
+
+    with mpl_plot_check():
+        pwl.plot([0.08 * u.TeV, 20 * u.TeV])
+
+    with mpl_plot_check():
+        pwl.plot_error([0.08 * u.TeV, 20 * u.TeV])
+
+    with mpl_plot_check():
+        pwl.plot(energy_bounds=energy_axis)
+
+    with mpl_plot_check():
+        pwl.plot_error(energy_bounds=energy_axis)
+
 
 def test_model_plot_sed_type():
     pwl = PowerLawSpectralModel(
@@ -754,6 +774,32 @@ def test_template_spectral_model_compound():
     assert np.allclose(new_model(energy), 2 * values)
 
 
+def test_template_spectral_model_options():
+    energy = [1.00e06, 1.25e06, 1.58e06, 1.99e06] * u.MeV
+    values = [4.39e-7, 1.96e-7, 8.80e-7, 3.94e-7] * u.Unit("MeV-1 s-1 sr-1")
+
+    model = TemplateSpectralModel(
+        energy=energy,
+        values=values,
+        interp_kwargs={"extrapolate": True, "method": "linear"},
+    )
+    assert np.allclose(model(energy), values)
+
+
+def test_covariance_spectral_model_compound():
+    model = TEST_MODELS[2]["model"] + TEST_MODELS[1]["model"]
+    covar = np.eye(len(model.parameters))
+    covar[0, -1] = 1.0
+    covar[-1, 0] = 1.0
+    covar[0, 1] = 1.0
+    covar[-1, -3] = 1.0
+
+    model.covariance = covar
+    assert_allclose(model.covariance.data, covar)
+    assert_allclose(model.model1.covariance.data, covar[:3, :3])
+    assert_allclose(model.model2.covariance.data, covar[-3:, -3:])
+
+
 def test_evaluate_spectral_model_compound():
     energy = [1.00e06, 1.25e06, 1.58e06, 1.99e06] * u.MeV
     model = TEST_MODELS[-2]["model"]
@@ -1193,7 +1239,6 @@ def test_template_ND_no_energy(tmpdir):
 
 @requires_data()
 def test_template_ND_EBL(tmpdir):
-
     # TODO: add RegionNDMap.read(format="xspec")
     # Create EBL data array
     filename = "$GAMMAPY_DATA/ebl/ebl_franceschini.fits.gz"
@@ -1215,10 +1260,10 @@ def test_template_ND_EBL(tmpdir):
     # Get energy values
     table_energy = Table.read(filename, hdu="ENERGIES")
     energy_lo = u.Quantity(
-        table_energy["ENERG_LO"], "keV", copy=False
+        table_energy["ENERG_LO"], "keV", copy=COPY_IF_NEEDED
     )  # unit not stored in file
     energy_hi = u.Quantity(
-        table_energy["ENERG_HI"], "keV", copy=False
+        table_energy["ENERG_HI"], "keV", copy=COPY_IF_NEEDED
     )  # unit not stored in file
     energy = np.sqrt(energy_lo * energy_hi)
 
@@ -1246,10 +1291,3 @@ def test_template_ND_EBL(tmpdir):
     assert_allclose(template_new.map.data, region_map.data)
     assert len(template.parameters) == 1
     assert_allclose(template.parameters["redshift"].value, 0.1)
-
-
-def test_is_norm_spectral_models():
-    for test_model in TEST_MODELS:
-        m = test_model["model"]
-        if m.tag[0] not in ["PiecewiseNormSpectralModel", "TemplateSpectralModel"]:
-            assert np.any([p._is_norm for p in m.parameters])
