@@ -168,7 +168,7 @@ def test_parameters_to_table(pars, tmp_path):
 
     table = pars.to_table()
     assert len(table) == 2
-    assert len(table.columns) == 11
+    assert len(table.columns) == 10
     assert table["link"][0] == "test"
     assert table["link"][1] == ""
 
@@ -184,7 +184,7 @@ def test_parameters_create_table():
     table = Parameters._create_default_table()
 
     assert len(table) == 0
-    assert len(table.columns) == 11
+    assert len(table.columns) == 10
 
     assert table.colnames == [
         "type",
@@ -195,7 +195,6 @@ def test_parameters_create_table():
         "min",
         "max",
         "frozen",
-        "is_norm",
         "link",
         "prior",
     ]
@@ -209,7 +208,6 @@ def test_parameters_create_table():
             ("min", "<f8"),
             ("max", "<f8"),
             ("frozen", "?"),
-            ("is_norm", "?"),
             ("link", "<U1"),
             ("prior", "<U1"),
         ]
@@ -247,6 +245,11 @@ def test_parameters_s():
     assert_allclose(pars[1].factor, 20)
     assert_allclose(pars[1].scale, 1)
 
+    # test for backward compatibilty
+    pars_dict[0]["is_norm"] = True
+    pars = Parameters.from_dict(pars_dict)
+    assert not hasattr(pars[0], "is_norm")
+
 
 def test_parameter_scan_values():
     p = Parameter(name="test", value=0, error=1)
