@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Statistics."""
+
 from .counts_statistic import CashCountsStatistic, WStatCountsStatistic
 from .fit_statistics import cash, cstat, get_wstat_gof_terms, get_wstat_mu_bkg, wstat
 from .fit_statistics_cython import (
@@ -7,7 +8,15 @@ from .fit_statistics_cython import (
     f_cash_root_cython,
     norm_bounds_cython,
 )
-from .variability import compute_chisq, compute_flux_doubling, compute_fpp, compute_fvar
+from .variability import (
+    TimmerKonig_lightcurve_simulator,
+    compute_chisq,
+    compute_flux_doubling,
+    compute_fpp,
+    compute_fvar,
+    discrete_correlation,
+    structure_function,
+)
 
 __all__ = [
     "cash",
@@ -24,4 +33,7 @@ __all__ = [
     "compute_fpp",
     "compute_flux_doubling",
     "compute_chisq",
+    "structure_function",
+    "discrete_correlation",
+    "TimmerKonig_lightcurve_simulator",
 ]
