@@ -1,5 +1,5 @@
-"""Astronomical coordinate calculation utility functions.
-"""
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
+"""Astronomical coordinate calculation utility functions."""
 from .fov import fov_to_sky, sky_to_fov
 from .other import (
     D_SUN_TO_GALACTIC_CENTER,
