@@ -88,6 +88,10 @@ def test_plot_map_rgb():
 
     axis = MapAxis([0, 1, 2, 3], node_type="edges")
     map_allsky = WcsNDMap.create(binsz=10 * u.deg, axes=[axis])
+
+    # Astropy 7 does not support uniformly 0 maps
+    map_allsky.data += 1
+
     with mpl_plot_check():
         plot_map_rgb(map_allsky)
 
@@ -138,3 +142,6 @@ def test_plot_distribution():
         axes, res = plot_distribution(
             wcs_map=map_, func="norm", kwargs_hist={"bins": 40}
         )
+
+        fig, ax = plt.subplots(nrows=1, ncols=1)
+        plot_distribution(map_empty, ax=ax)
