@@ -24,8 +24,8 @@ ARTIST_TO_LINE_PROPERTIES = {
     "ec": "markeredgecolor",
     "facecolor": "markerfacecolor",
     "fc": "markerfacecolor",
-    "linewidth": "markerwidth",
-    "lw": "markerwidth",
+    "linewidth": "markeredgewidth",
+    "lw": "markeredgewidth",
 }
 
 
@@ -51,7 +51,7 @@ def add_colorbar(img, ax, axes_loc=None, **kwargs):
 
     Examples
     --------
-    ::
+    .. testcode::
 
         from gammapy.maps import Map
         from gammapy.visualization import add_colorbar
@@ -70,7 +70,7 @@ def add_colorbar(img, ax, axes_loc=None, **kwargs):
         fig = plt.figure(figsize=(6, 3))
         ax = fig.add_subplot(111)
         map_.sum_over_axes().plot(ax=ax, add_cbar=True, axes_loc=axes_loc,
-                                  kwargs_colorbar=kwargs_colorbar)
+                                  kwargs_colorbar=kwargs_colorbar)  # doctest: +SKIP
 
     """
     kwargs.setdefault("use_gridspec", True)
@@ -341,8 +341,8 @@ def plot_distribution(
         )
         cells_in_grid = rows * cols
     else:
-        axes = ax
-        cells_in_grid = len(ax.flatten())
+        axes = np.array([ax])
+        cells_in_grid = axes.size
 
     if not isinstance(axes, np.ndarray):
         axes = np.array([axes])
